################################################## 
# OpcXmlDaSrv_services_types.py 
# generated by ZSI.generate.wsdl2python
##################################################


import ZSI
import ZSI.TCcompound
from ZSI.TC import ElementDeclaration,TypeDefinition
from ZSI.generate.pyclass import pyclass_type

##############################
# targetNamespace
# http://opcfoundation.org/webservices/XMLDA/1.0/
##############################

class ns3:
    targetNamespace = "http://opcfoundation.org/webservices/XMLDA/1.0/"

    class ItemIdentifier_Def(ZSI.TCcompound.ComplexType, TypeDefinition):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        type = (schema, "ItemIdentifier")
        def __init__(self, pname, ofwhat=(), attributes=None, extend=False, restrict=False, **kw):
            ns = ns3.ItemIdentifier_Def.schema
            TClist = []
            self.attribute_typecode_dict = attributes or {}
            if extend: TClist += ofwhat
            if restrict: TClist = ofwhat
            else:
                # attribute handling code
                self.attribute_typecode_dict["ItemPath"] = ZSI.TC.String()
                self.attribute_typecode_dict["ItemName"] = ZSI.TC.String()
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, pname=pname, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    return
            Holder.__name__ = "ItemIdentifier_Holder"
            self.pyclass = Holder

    class ReplyBase_Def(ZSI.TCcompound.ComplexType, TypeDefinition):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        type = (schema, "ReplyBase")
        def __init__(self, pname, ofwhat=(), attributes=None, extend=False, restrict=False, **kw):
            ns = ns3.ReplyBase_Def.schema
            TClist = []
            self.attribute_typecode_dict = attributes or {}
            if extend: TClist += ofwhat
            if restrict: TClist = ofwhat
            else:
                # attribute handling code
                self.attribute_typecode_dict["RcvTime"] = ZSI.TCtimes.gDateTime()
                self.attribute_typecode_dict["ReplyTime"] = ZSI.TCtimes.gDateTime()
                self.attribute_typecode_dict["ClientRequestHandle"] = ZSI.TC.String()
                self.attribute_typecode_dict["RevisedLocaleID"] = ZSI.TC.String()
                self.attribute_typecode_dict["ServerState"] = ns3.serverState_Def(None)
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, pname=pname, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    return
            Holder.__name__ = "ReplyBase_Holder"
            self.pyclass = Holder

    class serverState_Def(ZSI.TC.String, TypeDefinition):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        type = (schema, "serverState")
        def __init__(self, pname, **kw):
            ZSI.TC.String.__init__(self, pname, pyclass=None, **kw)
            class Holder(str):
                typecode = self
            self.pyclass = Holder

    class PropertyReplyList_Def(ZSI.TCcompound.ComplexType, TypeDefinition):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        type = (schema, "PropertyReplyList")
        def __init__(self, pname, ofwhat=(), attributes=None, extend=False, restrict=False, **kw):
            ns = ns3.PropertyReplyList_Def.schema
            TClist = [ns3.ItemProperty_Def(pname=(ns,"Properties"), aname="_Properties", minOccurs=0, maxOccurs="unbounded", nillable=False, encoded=kw.get("encoded"))]
            self.attribute_typecode_dict = attributes or {}
            if extend: TClist += ofwhat
            if restrict: TClist = ofwhat
            else:
                # attribute handling code
                self.attribute_typecode_dict["ItemPath"] = ZSI.TC.String()
                self.attribute_typecode_dict["ItemName"] = ZSI.TC.String()
                self.attribute_typecode_dict["ResultID"] = ZSI.TC.QName()
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, pname=pname, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._Properties = []
                    return
            Holder.__name__ = "PropertyReplyList_Holder"
            self.pyclass = Holder

    class ItemProperty_Def(ZSI.TCcompound.ComplexType, TypeDefinition):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        type = (schema, "ItemProperty")
        def __init__(self, pname, ofwhat=(), attributes=None, extend=False, restrict=False, **kw):
            ns = ns3.ItemProperty_Def.schema
            TClist = [ZSI.TC.AnyType(pname=(ns,"Value"), aname="_Value", minOccurs=0, maxOccurs=1, nillable=False, encoded=kw.get("encoded"))]
            self.attribute_typecode_dict = attributes or {}
            if extend: TClist += ofwhat
            if restrict: TClist = ofwhat
            else:
                # attribute handling code
                self.attribute_typecode_dict["Name"] = ZSI.TC.QName()
                self.attribute_typecode_dict["Description"] = ZSI.TC.String()
                self.attribute_typecode_dict["ItemPath"] = ZSI.TC.String()
                self.attribute_typecode_dict["ItemName"] = ZSI.TC.String()
                self.attribute_typecode_dict["ResultID"] = ZSI.TC.QName()
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, pname=pname, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._Value = None
                    return
            Holder.__name__ = "ItemProperty_Holder"
            self.pyclass = Holder

    class OPCError_Def(ZSI.TCcompound.ComplexType, TypeDefinition):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        type = (schema, "OPCError")
        def __init__(self, pname, ofwhat=(), attributes=None, extend=False, restrict=False, **kw):
            ns = ns3.OPCError_Def.schema
            TClist = [ZSI.TC.String(pname=(ns,"Text"), aname="_Text", minOccurs=0, maxOccurs=1, nillable=False, encoded=kw.get("encoded"))]
            self.attribute_typecode_dict = attributes or {}
            if extend: TClist += ofwhat
            if restrict: TClist = ofwhat
            else:
                # attribute handling code
                self.attribute_typecode_dict["ID"] = ZSI.TC.QName()
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, pname=pname, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._Text = None
                    return
            Holder.__name__ = "OPCError_Holder"
            self.pyclass = Holder

    class ArrayOfDouble_Def(ZSI.TCcompound.ComplexType, TypeDefinition):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        type = (schema, "ArrayOfDouble")
        def __init__(self, pname, ofwhat=(), attributes=None, extend=False, restrict=False, **kw):
            ns = ns3.ArrayOfDouble_Def.schema
            TClist = [ZSI.TCnumbers.FPdouble(pname=(ns,"double"), aname="_double", minOccurs=0, maxOccurs="unbounded", nillable=False, encoded=kw.get("encoded"))]
            self.attribute_typecode_dict = attributes or {}
            if extend: TClist += ofwhat
            if restrict: TClist = ofwhat
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, pname=pname, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._double = []
                    return
            Holder.__name__ = "ArrayOfDouble_Holder"
            self.pyclass = Holder

    class ArrayOfUnsignedShort_Def(ZSI.TCcompound.ComplexType, TypeDefinition):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        type = (schema, "ArrayOfUnsignedShort")
        def __init__(self, pname, ofwhat=(), attributes=None, extend=False, restrict=False, **kw):
            ns = ns3.ArrayOfUnsignedShort_Def.schema
            TClist = [ZSI.TCnumbers.IunsignedShort(pname=(ns,"unsignedShort"), aname="_unsignedShort", minOccurs=0, maxOccurs="unbounded", nillable=False, encoded=kw.get("encoded"))]
            self.attribute_typecode_dict = attributes or {}
            if extend: TClist += ofwhat
            if restrict: TClist = ofwhat
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, pname=pname, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._unsignedShort = []
                    return
            Holder.__name__ = "ArrayOfUnsignedShort_Holder"
            self.pyclass = Holder

    class ArrayOfDateTime_Def(ZSI.TCcompound.ComplexType, TypeDefinition):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        type = (schema, "ArrayOfDateTime")
        def __init__(self, pname, ofwhat=(), attributes=None, extend=False, restrict=False, **kw):
            ns = ns3.ArrayOfDateTime_Def.schema
            TClist = [ZSI.TCtimes.gDateTime(pname=(ns,"dateTime"), aname="_dateTime", minOccurs=0, maxOccurs="unbounded", nillable=False, encoded=kw.get("encoded"))]
            self.attribute_typecode_dict = attributes or {}
            if extend: TClist += ofwhat
            if restrict: TClist = ofwhat
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, pname=pname, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._dateTime = []
                    return
            Holder.__name__ = "ArrayOfDateTime_Holder"
            self.pyclass = Holder

    class ArrayOfAnyType_Def(ZSI.TCcompound.ComplexType, TypeDefinition):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        type = (schema, "ArrayOfAnyType")
        def __init__(self, pname, ofwhat=(), attributes=None, extend=False, restrict=False, **kw):
            ns = ns3.ArrayOfAnyType_Def.schema
            TClist = [ZSI.TC.AnyType(pname=(ns,"anyType"), aname="_anyType", minOccurs=0, maxOccurs="unbounded", nillable=True, encoded=kw.get("encoded"))]
            self.attribute_typecode_dict = attributes or {}
            if extend: TClist += ofwhat
            if restrict: TClist = ofwhat
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, pname=pname, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._anyType = []
                    return
            Holder.__name__ = "ArrayOfAnyType_Holder"
            self.pyclass = Holder

    class ArrayOfDecimal_Def(ZSI.TCcompound.ComplexType, TypeDefinition):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        type = (schema, "ArrayOfDecimal")
        def __init__(self, pname, ofwhat=(), attributes=None, extend=False, restrict=False, **kw):
            ns = ns3.ArrayOfDecimal_Def.schema
            TClist = [ZSI.TC.Decimal(pname=(ns,"decimal"), aname="_decimal", minOccurs=0, maxOccurs="unbounded", nillable=False, encoded=kw.get("encoded"))]
            self.attribute_typecode_dict = attributes or {}
            if extend: TClist += ofwhat
            if restrict: TClist = ofwhat
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, pname=pname, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._decimal = []
                    return
            Holder.__name__ = "ArrayOfDecimal_Holder"
            self.pyclass = Holder

    class ArrayOfByte_Def(ZSI.TCcompound.ComplexType, TypeDefinition):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        type = (schema, "ArrayOfByte")
        def __init__(self, pname, ofwhat=(), attributes=None, extend=False, restrict=False, **kw):
            ns = ns3.ArrayOfByte_Def.schema
            TClist = [ZSI.TCnumbers.Ibyte(pname=(ns,"byte"), aname="_byte", minOccurs=0, maxOccurs="unbounded", nillable=False, encoded=kw.get("encoded"))]
            self.attribute_typecode_dict = attributes or {}
            if extend: TClist += ofwhat
            if restrict: TClist = ofwhat
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, pname=pname, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._byte = []
                    return
            Holder.__name__ = "ArrayOfByte_Holder"
            self.pyclass = Holder

    class ArrayOfShort_Def(ZSI.TCcompound.ComplexType, TypeDefinition):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        type = (schema, "ArrayOfShort")
        def __init__(self, pname, ofwhat=(), attributes=None, extend=False, restrict=False, **kw):
            ns = ns3.ArrayOfShort_Def.schema
            TClist = [ZSI.TCnumbers.Ishort(pname=(ns,"short"), aname="_short", minOccurs=0, maxOccurs="unbounded", nillable=False, encoded=kw.get("encoded"))]
            self.attribute_typecode_dict = attributes or {}
            if extend: TClist += ofwhat
            if restrict: TClist = ofwhat
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, pname=pname, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._short = []
                    return
            Holder.__name__ = "ArrayOfShort_Holder"
            self.pyclass = Holder

    class ArrayOfBoolean_Def(ZSI.TCcompound.ComplexType, TypeDefinition):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        type = (schema, "ArrayOfBoolean")
        def __init__(self, pname, ofwhat=(), attributes=None, extend=False, restrict=False, **kw):
            ns = ns3.ArrayOfBoolean_Def.schema
            TClist = [ZSI.TC.Boolean(pname=(ns,"boolean"), aname="_boolean", minOccurs=0, maxOccurs="unbounded", nillable=False, encoded=kw.get("encoded"))]
            self.attribute_typecode_dict = attributes or {}
            if extend: TClist += ofwhat
            if restrict: TClist = ofwhat
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, pname=pname, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._boolean = []
                    return
            Holder.__name__ = "ArrayOfBoolean_Holder"
            self.pyclass = Holder

    class ArrayOfString_Def(ZSI.TCcompound.ComplexType, TypeDefinition):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        type = (schema, "ArrayOfString")
        def __init__(self, pname, ofwhat=(), attributes=None, extend=False, restrict=False, **kw):
            ns = ns3.ArrayOfString_Def.schema
            TClist = [ZSI.TC.String(pname=(ns,"string"), aname="_string", minOccurs=0, maxOccurs="unbounded", nillable=True, encoded=kw.get("encoded"))]
            self.attribute_typecode_dict = attributes or {}
            if extend: TClist += ofwhat
            if restrict: TClist = ofwhat
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, pname=pname, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._string = []
                    return
            Holder.__name__ = "ArrayOfString_Holder"
            self.pyclass = Holder

    class ArrayOfFloat_Def(ZSI.TCcompound.ComplexType, TypeDefinition):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        type = (schema, "ArrayOfFloat")
        def __init__(self, pname, ofwhat=(), attributes=None, extend=False, restrict=False, **kw):
            ns = ns3.ArrayOfFloat_Def.schema
            TClist = [ZSI.TCnumbers.FPfloat(pname=(ns,"float"), aname="_float", minOccurs=0, maxOccurs="unbounded", nillable=False, encoded=kw.get("encoded"))]
            self.attribute_typecode_dict = attributes or {}
            if extend: TClist += ofwhat
            if restrict: TClist = ofwhat
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, pname=pname, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._float = []
                    return
            Holder.__name__ = "ArrayOfFloat_Holder"
            self.pyclass = Holder

    class ArrayOfInt_Def(ZSI.TCcompound.ComplexType, TypeDefinition):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        type = (schema, "ArrayOfInt")
        def __init__(self, pname, ofwhat=(), attributes=None, extend=False, restrict=False, **kw):
            ns = ns3.ArrayOfInt_Def.schema
            TClist = [ZSI.TCnumbers.Iint(pname=(ns,"int"), aname="_int", minOccurs=0, maxOccurs="unbounded", nillable=False, encoded=kw.get("encoded"))]
            self.attribute_typecode_dict = attributes or {}
            if extend: TClist += ofwhat
            if restrict: TClist = ofwhat
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, pname=pname, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._int = []
                    return
            Holder.__name__ = "ArrayOfInt_Holder"
            self.pyclass = Holder

    class ArrayOfUnsignedInt_Def(ZSI.TCcompound.ComplexType, TypeDefinition):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        type = (schema, "ArrayOfUnsignedInt")
        def __init__(self, pname, ofwhat=(), attributes=None, extend=False, restrict=False, **kw):
            ns = ns3.ArrayOfUnsignedInt_Def.schema
            TClist = [ZSI.TCnumbers.IunsignedInt(pname=(ns,"unsignedInt"), aname="_unsignedInt", minOccurs=0, maxOccurs="unbounded", nillable=False, encoded=kw.get("encoded"))]
            self.attribute_typecode_dict = attributes or {}
            if extend: TClist += ofwhat
            if restrict: TClist = ofwhat
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, pname=pname, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._unsignedInt = []
                    return
            Holder.__name__ = "ArrayOfUnsignedInt_Holder"
            self.pyclass = Holder

    class ArrayOfLong_Def(ZSI.TCcompound.ComplexType, TypeDefinition):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        type = (schema, "ArrayOfLong")
        def __init__(self, pname, ofwhat=(), attributes=None, extend=False, restrict=False, **kw):
            ns = ns3.ArrayOfLong_Def.schema
            TClist = [ZSI.TCnumbers.Ilong(pname=(ns,"long"), aname="_long", minOccurs=0, maxOccurs="unbounded", nillable=False, encoded=kw.get("encoded"))]
            self.attribute_typecode_dict = attributes or {}
            if extend: TClist += ofwhat
            if restrict: TClist = ofwhat
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, pname=pname, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._long = []
                    return
            Holder.__name__ = "ArrayOfLong_Holder"
            self.pyclass = Holder

    class ArrayOfUnsignedLong_Def(ZSI.TCcompound.ComplexType, TypeDefinition):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        type = (schema, "ArrayOfUnsignedLong")
        def __init__(self, pname, ofwhat=(), attributes=None, extend=False, restrict=False, **kw):
            ns = ns3.ArrayOfUnsignedLong_Def.schema
            TClist = [ZSI.TCnumbers.IunsignedLong(pname=(ns,"unsignedLong"), aname="_unsignedLong", minOccurs=0, maxOccurs="unbounded", nillable=False, encoded=kw.get("encoded"))]
            self.attribute_typecode_dict = attributes or {}
            if extend: TClist += ofwhat
            if restrict: TClist = ofwhat
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, pname=pname, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._unsignedLong = []
                    return
            Holder.__name__ = "ArrayOfUnsignedLong_Holder"
            self.pyclass = Holder

    class RequestOptions_Def(ZSI.TCcompound.ComplexType, TypeDefinition):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        type = (schema, "RequestOptions")
        def __init__(self, pname, ofwhat=(), attributes=None, extend=False, restrict=False, **kw):
            ns = ns3.RequestOptions_Def.schema
            TClist = []
            self.attribute_typecode_dict = attributes or {}
            if extend: TClist += ofwhat
            if restrict: TClist = ofwhat
            else:
                # attribute handling code
                self.attribute_typecode_dict["ReturnErrorText"] = ZSI.TC.Boolean()
                self.attribute_typecode_dict["ReturnDiagnosticInfo"] = ZSI.TC.Boolean()
                self.attribute_typecode_dict["ReturnItemTime"] = ZSI.TC.Boolean()
                self.attribute_typecode_dict["ReturnItemPath"] = ZSI.TC.Boolean()
                self.attribute_typecode_dict["ReturnItemName"] = ZSI.TC.Boolean()
                self.attribute_typecode_dict["RequestDeadline"] = ZSI.TCtimes.gDateTime()
                self.attribute_typecode_dict["ClientRequestHandle"] = ZSI.TC.String()
                self.attribute_typecode_dict["LocaleID"] = ZSI.TC.String()
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, pname=pname, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    return
            Holder.__name__ = "RequestOptions_Holder"
            self.pyclass = Holder

    class SubscribeRequestItemList_Def(ZSI.TCcompound.ComplexType, TypeDefinition):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        type = (schema, "SubscribeRequestItemList")
        def __init__(self, pname, ofwhat=(), attributes=None, extend=False, restrict=False, **kw):
            ns = ns3.SubscribeRequestItemList_Def.schema
            TClist = [ns3.SubscribeRequestItem_Def(pname=(ns,"Items"), aname="_Items", minOccurs=0, maxOccurs="unbounded", nillable=False, encoded=kw.get("encoded"))]
            self.attribute_typecode_dict = attributes or {}
            if extend: TClist += ofwhat
            if restrict: TClist = ofwhat
            else:
                # attribute handling code
                self.attribute_typecode_dict["ItemPath"] = ZSI.TC.String()
                self.attribute_typecode_dict["ReqType"] = ZSI.TC.QName()
                self.attribute_typecode_dict["Deadband"] = ZSI.TCnumbers.FPfloat()
                self.attribute_typecode_dict["RequestedSamplingRate"] = ZSI.TCnumbers.Iint()
                self.attribute_typecode_dict["EnableBuffering"] = ZSI.TC.Boolean()
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, pname=pname, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._Items = []
                    return
            Holder.__name__ = "SubscribeRequestItemList_Holder"
            self.pyclass = Holder

    class SubscribeRequestItem_Def(ZSI.TCcompound.ComplexType, TypeDefinition):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        type = (schema, "SubscribeRequestItem")
        def __init__(self, pname, ofwhat=(), attributes=None, extend=False, restrict=False, **kw):
            ns = ns3.SubscribeRequestItem_Def.schema
            TClist = []
            self.attribute_typecode_dict = attributes or {}
            if extend: TClist += ofwhat
            if restrict: TClist = ofwhat
            else:
                # attribute handling code
                self.attribute_typecode_dict["ItemPath"] = ZSI.TC.String()
                self.attribute_typecode_dict["ReqType"] = ZSI.TC.QName()
                self.attribute_typecode_dict["ItemName"] = ZSI.TC.String()
                self.attribute_typecode_dict["ClientItemHandle"] = ZSI.TC.String()
                self.attribute_typecode_dict["Deadband"] = ZSI.TCnumbers.FPfloat()
                self.attribute_typecode_dict["RequestedSamplingRate"] = ZSI.TCnumbers.Iint()
                self.attribute_typecode_dict["EnableBuffering"] = ZSI.TC.Boolean()
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, pname=pname, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    return
            Holder.__name__ = "SubscribeRequestItem_Holder"
            self.pyclass = Holder

    class SubscribeReplyItemList_Def(ZSI.TCcompound.ComplexType, TypeDefinition):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        type = (schema, "SubscribeReplyItemList")
        def __init__(self, pname, ofwhat=(), attributes=None, extend=False, restrict=False, **kw):
            ns = ns3.SubscribeReplyItemList_Def.schema
            TClist = [ns3.SubscribeItemValue_Def(pname=(ns,"Items"), aname="_Items", minOccurs=0, maxOccurs="unbounded", nillable=False, encoded=kw.get("encoded"))]
            self.attribute_typecode_dict = attributes or {}
            if extend: TClist += ofwhat
            if restrict: TClist = ofwhat
            else:
                # attribute handling code
                self.attribute_typecode_dict["RevisedSamplingRate"] = ZSI.TCnumbers.Iint()
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, pname=pname, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._Items = []
                    return
            Holder.__name__ = "SubscribeReplyItemList_Holder"
            self.pyclass = Holder

    class SubscribeItemValue_Def(ZSI.TCcompound.ComplexType, TypeDefinition):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        type = (schema, "SubscribeItemValue")
        def __init__(self, pname, ofwhat=(), attributes=None, extend=False, restrict=False, **kw):
            ns = ns3.SubscribeItemValue_Def.schema
            TClist = [ns3.ItemValue_Def(pname=(ns,"ItemValue"), aname="_ItemValue", minOccurs=0, maxOccurs=1, nillable=False, encoded=kw.get("encoded"))]
            self.attribute_typecode_dict = attributes or {}
            if extend: TClist += ofwhat
            if restrict: TClist = ofwhat
            else:
                # attribute handling code
                self.attribute_typecode_dict["RevisedSamplingRate"] = ZSI.TCnumbers.Iint()
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, pname=pname, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._ItemValue = None
                    return
            Holder.__name__ = "SubscribeItemValue_Holder"
            self.pyclass = Holder

    class ItemValue_Def(ZSI.TCcompound.ComplexType, TypeDefinition):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        type = (schema, "ItemValue")
        def __init__(self, pname, ofwhat=(), attributes=None, extend=False, restrict=False, **kw):
            ns = ns3.ItemValue_Def.schema
            TClist = [ZSI.TC.String(pname=(ns,"DiagnosticInfo"), aname="_DiagnosticInfo", minOccurs=0, maxOccurs=1, nillable=False, encoded=kw.get("encoded")), ZSI.TC.AnyType(pname=(ns,"Value"), aname="_Value", minOccurs=0, maxOccurs=1, nillable=False, encoded=kw.get("encoded")), ns3.OPCQuality_Def(pname=(ns,"Quality"), aname="_Quality", minOccurs=0, maxOccurs=1, nillable=False, encoded=kw.get("encoded"))]
            self.attribute_typecode_dict = attributes or {}
            if extend: TClist += ofwhat
            if restrict: TClist = ofwhat
            else:
                # attribute handling code
                self.attribute_typecode_dict["ValueTypeQualifier"] = ZSI.TC.QName()
                self.attribute_typecode_dict["ItemPath"] = ZSI.TC.String()
                self.attribute_typecode_dict["ItemName"] = ZSI.TC.String()
                self.attribute_typecode_dict["ClientItemHandle"] = ZSI.TC.String()
                self.attribute_typecode_dict["Timestamp"] = ZSI.TCtimes.gDateTime()
                self.attribute_typecode_dict["ResultID"] = ZSI.TC.QName()
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, pname=pname, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._DiagnosticInfo = None
                    self._Value = None
                    self._Quality = None
                    return
            Holder.__name__ = "ItemValue_Holder"
            self.pyclass = Holder

    class OPCQuality_Def(ZSI.TCcompound.ComplexType, TypeDefinition):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        type = (schema, "OPCQuality")
        def __init__(self, pname, ofwhat=(), attributes=None, extend=False, restrict=False, **kw):
            ns = ns3.OPCQuality_Def.schema
            TClist = []
            self.attribute_typecode_dict = attributes or {}
            if extend: TClist += ofwhat
            if restrict: TClist = ofwhat
            else:
                # attribute handling code
                self.attribute_typecode_dict["QualityField"] = ns3.qualityBits_Def(None)
                self.attribute_typecode_dict["LimitField"] = ns3.limitBits_Def(None)
                self.attribute_typecode_dict["VendorField"] = ZSI.TCnumbers.IunsignedByte()
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, pname=pname, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    return
            Holder.__name__ = "OPCQuality_Holder"
            self.pyclass = Holder

    class qualityBits_Def(ZSI.TC.String, TypeDefinition):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        type = (schema, "qualityBits")
        def __init__(self, pname, **kw):
            ZSI.TC.String.__init__(self, pname, pyclass=None, **kw)
            class Holder(str):
                typecode = self
            self.pyclass = Holder

    class limitBits_Def(ZSI.TC.String, TypeDefinition):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        type = (schema, "limitBits")
        def __init__(self, pname, **kw):
            ZSI.TC.String.__init__(self, pname, pyclass=None, **kw)
            class Holder(str):
                typecode = self
            self.pyclass = Holder

    class SubscribePolledRefreshReplyItemList_Def(ZSI.TCcompound.ComplexType, TypeDefinition):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        type = (schema, "SubscribePolledRefreshReplyItemList")
        def __init__(self, pname, ofwhat=(), attributes=None, extend=False, restrict=False, **kw):
            ns = ns3.SubscribePolledRefreshReplyItemList_Def.schema
            TClist = [ns3.ItemValue_Def(pname=(ns,"Items"), aname="_Items", minOccurs=0, maxOccurs="unbounded", nillable=False, encoded=kw.get("encoded"))]
            self.attribute_typecode_dict = attributes or {}
            if extend: TClist += ofwhat
            if restrict: TClist = ofwhat
            else:
                # attribute handling code
                self.attribute_typecode_dict["SubscriptionHandle"] = ZSI.TC.String()
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, pname=pname, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._Items = []
                    return
            Holder.__name__ = "SubscribePolledRefreshReplyItemList_Holder"
            self.pyclass = Holder

    class ServerStatus_Def(ZSI.TCcompound.ComplexType, TypeDefinition):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        type = (schema, "ServerStatus")
        def __init__(self, pname, ofwhat=(), attributes=None, extend=False, restrict=False, **kw):
            ns = ns3.ServerStatus_Def.schema
            TClist = [ZSI.TC.String(pname=(ns,"StatusInfo"), aname="_StatusInfo", minOccurs=0, maxOccurs=1, nillable=False, encoded=kw.get("encoded")), ZSI.TC.String(pname=(ns,"VendorInfo"), aname="_VendorInfo", minOccurs=0, maxOccurs=1, nillable=False, encoded=kw.get("encoded")), ZSI.TC.String(pname=(ns,"SupportedLocaleIDs"), aname="_SupportedLocaleIDs", minOccurs=0, maxOccurs="unbounded", nillable=False, encoded=kw.get("encoded")), ns3.interfaceVersion_Def(pname=(ns,"SupportedInterfaceVersions"), aname="_SupportedInterfaceVersions", minOccurs=0, maxOccurs="unbounded", nillable=False, encoded=kw.get("encoded"))]
            self.attribute_typecode_dict = attributes or {}
            if extend: TClist += ofwhat
            if restrict: TClist = ofwhat
            else:
                # attribute handling code
                self.attribute_typecode_dict["StartTime"] = ZSI.TCtimes.gDateTime()
                self.attribute_typecode_dict["ProductVersion"] = ZSI.TC.String()
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, pname=pname, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._StatusInfo = None
                    self._VendorInfo = None
                    self._SupportedLocaleIDs = []
                    self._SupportedInterfaceVersions = []
                    return
            Holder.__name__ = "ServerStatus_Holder"
            self.pyclass = Holder

    class interfaceVersion_Def(ZSI.TC.String, TypeDefinition):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        type = (schema, "interfaceVersion")
        def __init__(self, pname, **kw):
            ZSI.TC.String.__init__(self, pname, pyclass=None, **kw)
            class Holder(str):
                typecode = self
            self.pyclass = Holder

    class browseFilter_Def(ZSI.TC.String, TypeDefinition):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        type = (schema, "browseFilter")
        def __init__(self, pname, **kw):
            ZSI.TC.String.__init__(self, pname, pyclass=None, **kw)
            class Holder(str):
                typecode = self
            self.pyclass = Holder

    class BrowseElement_Def(ZSI.TCcompound.ComplexType, TypeDefinition):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        type = (schema, "BrowseElement")
        def __init__(self, pname, ofwhat=(), attributes=None, extend=False, restrict=False, **kw):
            ns = ns3.BrowseElement_Def.schema
            TClist = [ns3.ItemProperty_Def(pname=(ns,"Properties"), aname="_Properties", minOccurs=0, maxOccurs="unbounded", nillable=False, encoded=kw.get("encoded"))]
            self.attribute_typecode_dict = attributes or {}
            if extend: TClist += ofwhat
            if restrict: TClist = ofwhat
            else:
                # attribute handling code
                self.attribute_typecode_dict["Name"] = ZSI.TC.String()
                self.attribute_typecode_dict["ItemPath"] = ZSI.TC.String()
                self.attribute_typecode_dict["ItemName"] = ZSI.TC.String()
                self.attribute_typecode_dict["IsItem"] = ZSI.TC.Boolean()
                self.attribute_typecode_dict["HasChildren"] = ZSI.TC.Boolean()
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, pname=pname, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._Properties = []
                    return
            Holder.__name__ = "BrowseElement_Holder"
            self.pyclass = Holder

    class ReadRequestItemList_Def(ZSI.TCcompound.ComplexType, TypeDefinition):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        type = (schema, "ReadRequestItemList")
        def __init__(self, pname, ofwhat=(), attributes=None, extend=False, restrict=False, **kw):
            ns = ns3.ReadRequestItemList_Def.schema
            TClist = [ns3.ReadRequestItem_Def(pname=(ns,"Items"), aname="_Items", minOccurs=0, maxOccurs="unbounded", nillable=False, encoded=kw.get("encoded"))]
            self.attribute_typecode_dict = attributes or {}
            if extend: TClist += ofwhat
            if restrict: TClist = ofwhat
            else:
                # attribute handling code
                self.attribute_typecode_dict["ItemPath"] = ZSI.TC.String()
                self.attribute_typecode_dict["ReqType"] = ZSI.TC.QName()
                self.attribute_typecode_dict["MaxAge"] = ZSI.TCnumbers.Iint()
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, pname=pname, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._Items = []
                    return
            Holder.__name__ = "ReadRequestItemList_Holder"
            self.pyclass = Holder

    class ReadRequestItem_Def(ZSI.TCcompound.ComplexType, TypeDefinition):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        type = (schema, "ReadRequestItem")
        def __init__(self, pname, ofwhat=(), attributes=None, extend=False, restrict=False, **kw):
            ns = ns3.ReadRequestItem_Def.schema
            TClist = []
            self.attribute_typecode_dict = attributes or {}
            if extend: TClist += ofwhat
            if restrict: TClist = ofwhat
            else:
                # attribute handling code
                self.attribute_typecode_dict["ItemPath"] = ZSI.TC.String()
                self.attribute_typecode_dict["ReqType"] = ZSI.TC.QName()
                self.attribute_typecode_dict["ItemName"] = ZSI.TC.String()
                self.attribute_typecode_dict["ClientItemHandle"] = ZSI.TC.String()
                self.attribute_typecode_dict["MaxAge"] = ZSI.TCnumbers.Iint()
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, pname=pname, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    return
            Holder.__name__ = "ReadRequestItem_Holder"
            self.pyclass = Holder

    class ReplyItemList_Def(ZSI.TCcompound.ComplexType, TypeDefinition):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        type = (schema, "ReplyItemList")
        def __init__(self, pname, ofwhat=(), attributes=None, extend=False, restrict=False, **kw):
            ns = ns3.ReplyItemList_Def.schema
            TClist = [ns3.ItemValue_Def(pname=(ns,"Items"), aname="_Items", minOccurs=0, maxOccurs="unbounded", nillable=False, encoded=kw.get("encoded"))]
            self.attribute_typecode_dict = attributes or {}
            if extend: TClist += ofwhat
            if restrict: TClist = ofwhat
            else:
                # attribute handling code
                self.attribute_typecode_dict["Reserved"] = ZSI.TC.String()
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, pname=pname, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._Items = []
                    return
            Holder.__name__ = "ReplyItemList_Holder"
            self.pyclass = Holder

    class WriteRequestItemList_Def(ZSI.TCcompound.ComplexType, TypeDefinition):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        type = (schema, "WriteRequestItemList")
        def __init__(self, pname, ofwhat=(), attributes=None, extend=False, restrict=False, **kw):
            ns = ns3.WriteRequestItemList_Def.schema
            TClist = [ns3.ItemValue_Def(pname=(ns,"Items"), aname="_Items", minOccurs=0, maxOccurs="unbounded", nillable=False, encoded=kw.get("encoded"))]
            self.attribute_typecode_dict = attributes or {}
            if extend: TClist += ofwhat
            if restrict: TClist = ofwhat
            else:
                # attribute handling code
                self.attribute_typecode_dict["ItemPath"] = ZSI.TC.String()
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, pname=pname, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._Items = []
                    return
            Holder.__name__ = "WriteRequestItemList_Holder"
            self.pyclass = Holder

    class GetProperties_Dec(ZSI.TCcompound.ComplexType, ElementDeclaration):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        literal = "GetProperties"
        def __init__(self, **kw):
            ns = ns3.GetProperties_Dec.schema
            TClist = [ns3.ItemIdentifier_Def(pname=(ns,"ItemIDs"), aname="_ItemIDs", minOccurs=0, maxOccurs="unbounded", nillable=False, encoded=kw.get("encoded")), ZSI.TC.QName(pname=(ns,"PropertyNames"), aname="_PropertyNames", minOccurs=0, maxOccurs="unbounded", nillable=False, encoded=kw.get("encoded"))]
            kw["pname"] = ("http://opcfoundation.org/webservices/XMLDA/1.0/","GetProperties")
            kw["aname"] = "_GetProperties"
            self.attribute_typecode_dict = {}
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, inorder=0, **kw)
            # attribute handling code
            self.attribute_typecode_dict["LocaleID"] = ZSI.TC.String()
            self.attribute_typecode_dict["ClientRequestHandle"] = ZSI.TC.String()
            self.attribute_typecode_dict["ItemPath"] = ZSI.TC.String()
            self.attribute_typecode_dict["ReturnAllProperties"] = ZSI.TC.Boolean()
            self.attribute_typecode_dict["ReturnPropertyValues"] = ZSI.TC.Boolean()
            self.attribute_typecode_dict["ReturnErrorText"] = ZSI.TC.Boolean()
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._ItemIDs = []
                    self._PropertyNames = []
                    return
            Holder.__name__ = "GetProperties_Holder"
            self.pyclass = Holder

    class GetPropertiesResponse_Dec(ZSI.TCcompound.ComplexType, ElementDeclaration):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        literal = "GetPropertiesResponse"
        def __init__(self, **kw):
            ns = ns3.GetPropertiesResponse_Dec.schema
            TClist = [ns3.ReplyBase_Def(pname=(ns,"GetPropertiesResult"), aname="_GetPropertiesResult", minOccurs=0, maxOccurs=1, nillable=False, encoded=kw.get("encoded")), ns3.PropertyReplyList_Def(pname=(ns,"PropertyLists"), aname="_PropertyLists", minOccurs=0, maxOccurs="unbounded", nillable=False, encoded=kw.get("encoded")), ns3.OPCError_Def(pname=(ns,"Errors"), aname="_Errors", minOccurs=0, maxOccurs="unbounded", nillable=False, encoded=kw.get("encoded"))]
            kw["pname"] = ("http://opcfoundation.org/webservices/XMLDA/1.0/","GetPropertiesResponse")
            kw["aname"] = "_GetPropertiesResponse"
            self.attribute_typecode_dict = {}
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._GetPropertiesResult = None
                    self._PropertyLists = []
                    self._Errors = []
                    return
            Holder.__name__ = "GetPropertiesResponse_Holder"
            self.pyclass = Holder

    class Subscribe_Dec(ZSI.TCcompound.ComplexType, ElementDeclaration):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        literal = "Subscribe"
        def __init__(self, **kw):
            ns = ns3.Subscribe_Dec.schema
            TClist = [ns3.RequestOptions_Def(pname=(ns,"Options"), aname="_Options", minOccurs=0, maxOccurs=1, nillable=False, encoded=kw.get("encoded")), ns3.SubscribeRequestItemList_Def(pname=(ns,"ItemList"), aname="_ItemList", minOccurs=0, maxOccurs=1, nillable=False, encoded=kw.get("encoded"))]
            kw["pname"] = ("http://opcfoundation.org/webservices/XMLDA/1.0/","Subscribe")
            kw["aname"] = "_Subscribe"
            self.attribute_typecode_dict = {}
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, inorder=0, **kw)
            # attribute handling code
            self.attribute_typecode_dict["ReturnValuesOnReply"] = ZSI.TC.Boolean()
            self.attribute_typecode_dict["SubscriptionPingRate"] = ZSI.TCnumbers.Iint()
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._Options = None
                    self._ItemList = None
                    return
            Holder.__name__ = "Subscribe_Holder"
            self.pyclass = Holder

    class SubscribeResponse_Dec(ZSI.TCcompound.ComplexType, ElementDeclaration):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        literal = "SubscribeResponse"
        def __init__(self, **kw):
            ns = ns3.SubscribeResponse_Dec.schema
            TClist = [ns3.ReplyBase_Def(pname=(ns,"SubscribeResult"), aname="_SubscribeResult", minOccurs=0, maxOccurs=1, nillable=False, encoded=kw.get("encoded")), ns3.SubscribeReplyItemList_Def(pname=(ns,"RItemList"), aname="_RItemList", minOccurs=0, maxOccurs=1, nillable=False, encoded=kw.get("encoded")), ns3.OPCError_Def(pname=(ns,"Errors"), aname="_Errors", minOccurs=0, maxOccurs="unbounded", nillable=False, encoded=kw.get("encoded"))]
            kw["pname"] = ("http://opcfoundation.org/webservices/XMLDA/1.0/","SubscribeResponse")
            kw["aname"] = "_SubscribeResponse"
            self.attribute_typecode_dict = {}
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, inorder=0, **kw)
            # attribute handling code
            self.attribute_typecode_dict["ServerSubHandle"] = ZSI.TC.String()
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._SubscribeResult = None
                    self._RItemList = None
                    self._Errors = []
                    return
            Holder.__name__ = "SubscribeResponse_Holder"
            self.pyclass = Holder

    class SubscriptionPolledRefresh_Dec(ZSI.TCcompound.ComplexType, ElementDeclaration):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        literal = "SubscriptionPolledRefresh"
        def __init__(self, **kw):
            ns = ns3.SubscriptionPolledRefresh_Dec.schema
            TClist = [ns3.RequestOptions_Def(pname=(ns,"Options"), aname="_Options", minOccurs=0, maxOccurs=1, nillable=False, encoded=kw.get("encoded")), ZSI.TC.String(pname=(ns,"ServerSubHandles"), aname="_ServerSubHandles", minOccurs=0, maxOccurs="unbounded", nillable=False, encoded=kw.get("encoded"))]
            kw["pname"] = ("http://opcfoundation.org/webservices/XMLDA/1.0/","SubscriptionPolledRefresh")
            kw["aname"] = "_SubscriptionPolledRefresh"
            self.attribute_typecode_dict = {}
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, inorder=0, **kw)
            # attribute handling code
            self.attribute_typecode_dict["HoldTime"] = ZSI.TCtimes.gDateTime()
            self.attribute_typecode_dict["WaitTime"] = ZSI.TCnumbers.Iint()
            self.attribute_typecode_dict["ReturnAllItems"] = ZSI.TC.Boolean()
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._Options = None
                    self._ServerSubHandles = []
                    return
            Holder.__name__ = "SubscriptionPolledRefresh_Holder"
            self.pyclass = Holder

    class SubscriptionPolledRefreshResponse_Dec(ZSI.TCcompound.ComplexType, ElementDeclaration):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        literal = "SubscriptionPolledRefreshResponse"
        def __init__(self, **kw):
            ns = ns3.SubscriptionPolledRefreshResponse_Dec.schema
            TClist = [ns3.ReplyBase_Def(pname=(ns,"SubscriptionPolledRefreshResult"), aname="_SubscriptionPolledRefreshResult", minOccurs=0, maxOccurs=1, nillable=False, encoded=kw.get("encoded")), ZSI.TC.String(pname=(ns,"InvalidServerSubHandles"), aname="_InvalidServerSubHandles", minOccurs=0, maxOccurs="unbounded", nillable=False, encoded=kw.get("encoded")), ns3.SubscribePolledRefreshReplyItemList_Def(pname=(ns,"RItemList"), aname="_RItemList", minOccurs=0, maxOccurs="unbounded", nillable=False, encoded=kw.get("encoded")), ns3.OPCError_Def(pname=(ns,"Errors"), aname="_Errors", minOccurs=0, maxOccurs="unbounded", nillable=False, encoded=kw.get("encoded"))]
            kw["pname"] = ("http://opcfoundation.org/webservices/XMLDA/1.0/","SubscriptionPolledRefreshResponse")
            kw["aname"] = "_SubscriptionPolledRefreshResponse"
            self.attribute_typecode_dict = {}
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, inorder=0, **kw)
            # attribute handling code
            self.attribute_typecode_dict["DataBufferOverflow"] = ZSI.TC.Boolean()
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._SubscriptionPolledRefreshResult = None
                    self._InvalidServerSubHandles = []
                    self._RItemList = []
                    self._Errors = []
                    return
            Holder.__name__ = "SubscriptionPolledRefreshResponse_Holder"
            self.pyclass = Holder

    class SubscriptionCancel_Dec(ZSI.TCcompound.ComplexType, ElementDeclaration):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        literal = "SubscriptionCancel"
        def __init__(self, **kw):
            ns = ns3.SubscriptionCancel_Dec.schema
            TClist = []
            kw["pname"] = ("http://opcfoundation.org/webservices/XMLDA/1.0/","SubscriptionCancel")
            kw["aname"] = "_SubscriptionCancel"
            self.attribute_typecode_dict = {}
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, inorder=0, **kw)
            # attribute handling code
            self.attribute_typecode_dict["ServerSubHandle"] = ZSI.TC.String()
            self.attribute_typecode_dict["ClientRequestHandle"] = ZSI.TC.String()
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    return
            Holder.__name__ = "SubscriptionCancel_Holder"
            self.pyclass = Holder

    class SubscriptionCancelResponse_Dec(ZSI.TCcompound.ComplexType, ElementDeclaration):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        literal = "SubscriptionCancelResponse"
        def __init__(self, **kw):
            ns = ns3.SubscriptionCancelResponse_Dec.schema
            TClist = []
            kw["pname"] = ("http://opcfoundation.org/webservices/XMLDA/1.0/","SubscriptionCancelResponse")
            kw["aname"] = "_SubscriptionCancelResponse"
            self.attribute_typecode_dict = {}
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, inorder=0, **kw)
            # attribute handling code
            self.attribute_typecode_dict["ClientRequestHandle"] = ZSI.TC.String()
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    return
            Holder.__name__ = "SubscriptionCancelResponse_Holder"
            self.pyclass = Holder

    class GetStatus_Dec(ZSI.TCcompound.ComplexType, ElementDeclaration):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        literal = "GetStatus"
        def __init__(self, **kw):
            ns = ns3.GetStatus_Dec.schema
            TClist = []
            kw["pname"] = ("http://opcfoundation.org/webservices/XMLDA/1.0/","GetStatus")
            kw["aname"] = "_GetStatus"
            self.attribute_typecode_dict = {}
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, inorder=0, **kw)
            # attribute handling code
            self.attribute_typecode_dict["LocaleID"] = ZSI.TC.String()
            self.attribute_typecode_dict["ClientRequestHandle"] = ZSI.TC.String()
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    return
            Holder.__name__ = "GetStatus_Holder"
            self.pyclass = Holder

    class GetStatusResponse_Dec(ZSI.TCcompound.ComplexType, ElementDeclaration):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        literal = "GetStatusResponse"
        def __init__(self, **kw):
            ns = ns3.GetStatusResponse_Dec.schema
            TClist = [ns3.ReplyBase_Def(pname=(ns,"GetStatusResult"), aname="_GetStatusResult", minOccurs=0, maxOccurs=1, nillable=False, encoded=kw.get("encoded")), ns3.ServerStatus_Def(pname=(ns,"Status"), aname="_Status", minOccurs=0, maxOccurs=1, nillable=False, encoded=kw.get("encoded"))]
            kw["pname"] = ("http://opcfoundation.org/webservices/XMLDA/1.0/","GetStatusResponse")
            kw["aname"] = "_GetStatusResponse"
            self.attribute_typecode_dict = {}
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._GetStatusResult = None
                    self._Status = None
                    return
            Holder.__name__ = "GetStatusResponse_Holder"
            self.pyclass = Holder

    class Browse_Dec(ZSI.TCcompound.ComplexType, ElementDeclaration):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        literal = "Browse"
        def __init__(self, **kw):
            ns = ns3.Browse_Dec.schema
            TClist = [ZSI.TC.QName(pname=(ns,"PropertyNames"), aname="_PropertyNames", minOccurs=0, maxOccurs="unbounded", nillable=False, encoded=kw.get("encoded"))]
            kw["pname"] = ("http://opcfoundation.org/webservices/XMLDA/1.0/","Browse")
            kw["aname"] = "_Browse"
            self.attribute_typecode_dict = {}
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, inorder=0, **kw)
            # attribute handling code
            self.attribute_typecode_dict["LocaleID"] = ZSI.TC.String()
            self.attribute_typecode_dict["ClientRequestHandle"] = ZSI.TC.String()
            self.attribute_typecode_dict["ItemPath"] = ZSI.TC.String()
            self.attribute_typecode_dict["ItemName"] = ZSI.TC.String()
            self.attribute_typecode_dict["ContinuationPoint"] = ZSI.TC.String()
            self.attribute_typecode_dict["MaxElementsReturned"] = ZSI.TCnumbers.Iint()
            self.attribute_typecode_dict["BrowseFilter"] = ns3.browseFilter_Def(None)
            self.attribute_typecode_dict["ElementNameFilter"] = ZSI.TC.String()
            self.attribute_typecode_dict["VendorFilter"] = ZSI.TC.String()
            self.attribute_typecode_dict["ReturnAllProperties"] = ZSI.TC.Boolean()
            self.attribute_typecode_dict["ReturnPropertyValues"] = ZSI.TC.Boolean()
            self.attribute_typecode_dict["ReturnErrorText"] = ZSI.TC.Boolean()
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._PropertyNames = []
                    return
            Holder.__name__ = "Browse_Holder"
            self.pyclass = Holder

    class BrowseResponse_Dec(ZSI.TCcompound.ComplexType, ElementDeclaration):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        literal = "BrowseResponse"
        def __init__(self, **kw):
            ns = ns3.BrowseResponse_Dec.schema
            TClist = [ns3.ReplyBase_Def(pname=(ns,"BrowseResult"), aname="_BrowseResult", minOccurs=0, maxOccurs=1, nillable=False, encoded=kw.get("encoded")), ns3.BrowseElement_Def(pname=(ns,"Elements"), aname="_Elements", minOccurs=0, maxOccurs="unbounded", nillable=False, encoded=kw.get("encoded")), ns3.OPCError_Def(pname=(ns,"Errors"), aname="_Errors", minOccurs=0, maxOccurs="unbounded", nillable=False, encoded=kw.get("encoded"))]
            kw["pname"] = ("http://opcfoundation.org/webservices/XMLDA/1.0/","BrowseResponse")
            kw["aname"] = "_BrowseResponse"
            self.attribute_typecode_dict = {}
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, inorder=0, **kw)
            # attribute handling code
            self.attribute_typecode_dict["ContinuationPoint"] = ZSI.TC.String()
            self.attribute_typecode_dict["MoreElements"] = ZSI.TC.Boolean()
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._BrowseResult = None
                    self._Elements = []
                    self._Errors = []
                    return
            Holder.__name__ = "BrowseResponse_Holder"
            self.pyclass = Holder

    class Read_Dec(ZSI.TCcompound.ComplexType, ElementDeclaration):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        literal = "Read"
        def __init__(self, **kw):
            ns = ns3.Read_Dec.schema
            TClist = [ns3.RequestOptions_Def(pname=(ns,"Options"), aname="_Options", minOccurs=0, maxOccurs=1, nillable=False, encoded=kw.get("encoded")), ns3.ReadRequestItemList_Def(pname=(ns,"ItemList"), aname="_ItemList", minOccurs=0, maxOccurs=1, nillable=False, encoded=kw.get("encoded"))]
            kw["pname"] = ("http://opcfoundation.org/webservices/XMLDA/1.0/","Read")
            kw["aname"] = "_Read"
            self.attribute_typecode_dict = {}
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._Options = None
                    self._ItemList = None
                    return
            Holder.__name__ = "Read_Holder"
            self.pyclass = Holder

    class ReadResponse_Dec(ZSI.TCcompound.ComplexType, ElementDeclaration):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        literal = "ReadResponse"
        def __init__(self, **kw):
            ns = ns3.ReadResponse_Dec.schema
            TClist = [ns3.ReplyBase_Def(pname=(ns,"ReadResult"), aname="_ReadResult", minOccurs=0, maxOccurs=1, nillable=False, encoded=kw.get("encoded")), ns3.ReplyItemList_Def(pname=(ns,"RItemList"), aname="_RItemList", minOccurs=0, maxOccurs=1, nillable=False, encoded=kw.get("encoded")), ns3.OPCError_Def(pname=(ns,"Errors"), aname="_Errors", minOccurs=0, maxOccurs="unbounded", nillable=False, encoded=kw.get("encoded"))]
            kw["pname"] = ("http://opcfoundation.org/webservices/XMLDA/1.0/","ReadResponse")
            kw["aname"] = "_ReadResponse"
            self.attribute_typecode_dict = {}
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._ReadResult = None
                    self._RItemList = None
                    self._Errors = []
                    return
            Holder.__name__ = "ReadResponse_Holder"
            self.pyclass = Holder

    class Write_Dec(ZSI.TCcompound.ComplexType, ElementDeclaration):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        literal = "Write"
        def __init__(self, **kw):
            ns = ns3.Write_Dec.schema
            TClist = [ns3.RequestOptions_Def(pname=(ns,"Options"), aname="_Options", minOccurs=0, maxOccurs=1, nillable=False, encoded=kw.get("encoded")), ns3.WriteRequestItemList_Def(pname=(ns,"ItemList"), aname="_ItemList", minOccurs=0, maxOccurs=1, nillable=False, encoded=kw.get("encoded"))]
            kw["pname"] = ("http://opcfoundation.org/webservices/XMLDA/1.0/","Write")
            kw["aname"] = "_Write"
            self.attribute_typecode_dict = {}
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, inorder=0, **kw)
            # attribute handling code
            self.attribute_typecode_dict["ReturnValuesOnReply"] = ZSI.TC.Boolean()
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._Options = None
                    self._ItemList = None
                    return
            Holder.__name__ = "Write_Holder"
            self.pyclass = Holder

    class WriteResponse_Dec(ZSI.TCcompound.ComplexType, ElementDeclaration):
        schema = "http://opcfoundation.org/webservices/XMLDA/1.0/"
        literal = "WriteResponse"
        def __init__(self, **kw):
            ns = ns3.WriteResponse_Dec.schema
            TClist = [ns3.ReplyBase_Def(pname=(ns,"WriteResult"), aname="_WriteResult", minOccurs=0, maxOccurs=1, nillable=False, encoded=kw.get("encoded")), ns3.ReplyItemList_Def(pname=(ns,"RItemList"), aname="_RItemList", minOccurs=0, maxOccurs=1, nillable=False, encoded=kw.get("encoded")), ns3.OPCError_Def(pname=(ns,"Errors"), aname="_Errors", minOccurs=0, maxOccurs="unbounded", nillable=False, encoded=kw.get("encoded"))]
            kw["pname"] = ("http://opcfoundation.org/webservices/XMLDA/1.0/","WriteResponse")
            kw["aname"] = "_WriteResponse"
            self.attribute_typecode_dict = {}
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    self._WriteResult = None
                    self._RItemList = None
                    self._Errors = []
                    return
            Holder.__name__ = "WriteResponse_Holder"
            self.pyclass = Holder

# end class ns3 (tns: http://opcfoundation.org/webservices/XMLDA/1.0/)



#!/usr/bin/env python

############################################################################
# Joshua R. Boverhof, LBNL
# See LBNLCopyright for copyright notice!
###########################################################################
import sys, unittest
from ServiceTest import ServiceTestCase, ServiceTestSuite, TestException

"""
Unittest for contacting the WhiteMesa web service for rpc/literal tests.

WSDL: http://www.whitemesa.net/wsdl/test-rpc-lit.wsdl

"""

CONFIG_FILE = 'config.txt'
CONFIG_SECTION = 'WSDL'
SERVICE_NAME = 'WhiteMesa'
PORT_NAME = 'Soap11TestRpcLitPort'


class WhiteMesaTest(ServiceTestCase):
    """Test case for ZipCodeResolver Web service
    """
    name = "test_WhiteMesa"

    def getInputMessageInstance(self, operationName):
        """Returns an instance of the input message to send for this operation.
        Grap the SOAP 1.1 port.
           operationName -- WSDL port operation name
        """
        service = self._wsm._wsdl.services[0]
        port = service.ports[1]
        try:
            self._checkPort(port, operationName)
        except TestException, ex:
            raise TestException('Service(%s)' %service.name, *ex.args)

        for operation in port.getBinding().getPortType().operations:
            if operation.name == operationName:
                break
        else:
            raise TestException, 'Missing operation (%s) in portType operations'  %operationName

        inputMsgName = '%s' %operation.input.message[1]
        if self._moduleDict.has_key(self._serviceModuleName):
            sm = self._moduleDict[self._serviceModuleName]
            if sm.__dict__.has_key(inputMsgName):
                inputMsgWrapper = sm.__dict__[inputMsgName]()
                return inputMsgWrapper
            else:
                raise TestException, 'service missing input message (%s)' %(inputMsgName)

        raise TestException, 'port(%s) does not define operation %s' \
            %(port.name, operationName)

    def setUp(self):
        self._portName = PORT_NAME
        ServiceTestCase.setSection(self,self.name)
        ServiceTestCase.setUp(self)

    def test_EchoBoolean(self):
        operationName = 'echoBoolean'
        request = self.getInputMessageInstance(operationName)
        request._inputBoolean = True
        response = self.RPC(operationName, request)


def makeTestSuite():
    suite = ServiceTestSuite()
    suite.addTest(unittest.makeSuite(WhiteMesaTest, 'test_'))
    return suite


if __name__ == "__main__" :
    unittest.TestProgram(defaultTest="makeTestSuite")



################################################## 
# OpcXmlDaSrv_services.py 
# generated by ZSI.generate.wsdl2python
##################################################


from OpcXmlDaSrv_services_types import *
import urlparse, types
from ZSI.TCcompound import ComplexType, Struct
from ZSI import client
import ZSI

# Locator
class OpcXmlDaSrvLocator:
    OpcXmlDaSrvSoap_address = "http://tswinc.us/XMLDADemo/ts_sim/OpcDaGateway.asmx"
    def getOpcXmlDaSrvSoapAddress(self):
        return OpcXmlDaSrvLocator.OpcXmlDaSrvSoap_address
    def getOpcXmlDaSrvSoap(self, url=None, **kw):
        return OpcXmlDaSrvSoapSOAP(url or OpcXmlDaSrvLocator.OpcXmlDaSrvSoap_address, **kw)

# Methods
class OpcXmlDaSrvSoapSOAP:
    def __init__(self, url, **kw):
        kw.setdefault("readerclass", None)
        kw.setdefault("writerclass", None)
        # no resource properties
        self.binding = client.Binding(url=url, **kw)
        # no ws-addressing

    # op: GetProperties
    def GetProperties(self, request):
        if isinstance(request, GetPropertiesSoapIn) is False:
            raise TypeError, "%s incorrect request type" % (request.__class__)
        kw = {}
        # no input wsaction
        self.binding.Send(None, None, request, soapaction="http://opcfoundation.org/webservices/XMLDA/1.0/GetProperties", **kw)
        # no output wsaction
        response = self.binding.Receive(GetPropertiesSoapOut.typecode)
        if isinstance(response, GetPropertiesSoapOut.typecode.pyclass) is False:
            raise TypeError, "%s incorrect response type" % (response.__class__)
        return response

    # op: Subscribe
    def Subscribe(self, request):
        if isinstance(request, SubscribeSoapIn) is False:
            raise TypeError, "%s incorrect request type" % (request.__class__)
        kw = {}
        # no input wsaction
        self.binding.Send(None, None, request, soapaction="http://opcfoundation.org/webservices/XMLDA/1.0/Subscribe", **kw)
        # no output wsaction
        response = self.binding.Receive(SubscribeSoapOut.typecode)
        if isinstance(response, SubscribeSoapOut.typecode.pyclass) is False:
            raise TypeError, "%s incorrect response type" % (response.__class__)
        return response

    # op: SubscriptionPolledRefresh
    def SubscriptionPolledRefresh(self, request):
        if isinstance(request, SubscriptionPolledRefreshSoapIn) is False:
            raise TypeError, "%s incorrect request type" % (request.__class__)
        kw = {}
        # no input wsaction
        self.binding.Send(None, None, request, soapaction="http://opcfoundation.org/webservices/XMLDA/1.0/SubscriptionPolledRefresh", **kw)
        # no output wsaction
        response = self.binding.Receive(SubscriptionPolledRefreshSoapOut.typecode)
        if isinstance(response, SubscriptionPolledRefreshSoapOut.typecode.pyclass) is False:
            raise TypeError, "%s incorrect response type" % (response.__class__)
        return response

    # op: SubscriptionCancel
    def SubscriptionCancel(self, request):
        if isinstance(request, SubscriptionCancelSoapIn) is False:
            raise TypeError, "%s incorrect request type" % (request.__class__)
        kw = {}
        # no input wsaction
        self.binding.Send(None, None, request, soapaction="http://opcfoundation.org/webservices/XMLDA/1.0/SubscriptionCancel", **kw)
        # no output wsaction
        response = self.binding.Receive(SubscriptionCancelSoapOut.typecode)
        if isinstance(response, SubscriptionCancelSoapOut.typecode.pyclass) is False:
            raise TypeError, "%s incorrect response type" % (response.__class__)
        return response

    # op: GetStatus
    def GetStatus(self, request):
        if isinstance(request, GetStatusSoapIn) is False:
            raise TypeError, "%s incorrect request type" % (request.__class__)
        kw = {}
        # no input wsaction
        self.binding.Send(None, None, request, soapaction="http://opcfoundation.org/webservices/XMLDA/1.0/GetStatus", **kw)
        # no output wsaction
        response = self.binding.Receive(GetStatusSoapOut.typecode)
        if isinstance(response, GetStatusSoapOut.typecode.pyclass) is False:
            raise TypeError, "%s incorrect response type" % (response.__class__)
        return response

    # op: Browse
    def Browse(self, request):
        if isinstance(request, BrowseSoapIn) is False:
            raise TypeError, "%s incorrect request type" % (request.__class__)
        kw = {}
        # no input wsaction
        self.binding.Send(None, None, request, soapaction="http://opcfoundation.org/webservices/XMLDA/1.0/Browse", **kw)
        # no output wsaction
        response = self.binding.Receive(BrowseSoapOut.typecode)
        if isinstance(response, BrowseSoapOut.typecode.pyclass) is False:
            raise TypeError, "%s incorrect response type" % (response.__class__)
        return response

    # op: Read
    def Read(self, request):
        if isinstance(request, ReadSoapIn) is False:
            raise TypeError, "%s incorrect request type" % (request.__class__)
        kw = {}
        # no input wsaction
        self.binding.Send(None, None, request, soapaction="http://opcfoundation.org/webservices/XMLDA/1.0/Read", **kw)
        # no output wsaction
        response = self.binding.Receive(ReadSoapOut.typecode)
        if isinstance(response, ReadSoapOut.typecode.pyclass) is False:
            raise TypeError, "%s incorrect response type" % (response.__class__)
        return response

    # op: Write
    def Write(self, request):
        if isinstance(request, WriteSoapIn) is False:
            raise TypeError, "%s incorrect request type" % (request.__class__)
        kw = {}
        # no input wsaction
        self.binding.Send(None, None, request, soapaction="http://opcfoundation.org/webservices/XMLDA/1.0/Write", **kw)
        # no output wsaction
        response = self.binding.Receive(WriteSoapOut.typecode)
        if isinstance(response, WriteSoapOut.typecode.pyclass) is False:
            raise TypeError, "%s incorrect response type" % (response.__class__)
        return response

GetPropertiesSoapIn = ns3.GetProperties_Dec().pyclass

GetPropertiesSoapOut = ns3.GetPropertiesResponse_Dec().pyclass

SubscribeSoapIn = ns3.Subscribe_Dec().pyclass

SubscribeSoapOut = ns3.SubscribeResponse_Dec().pyclass

SubscriptionPolledRefreshSoapIn = ns3.SubscriptionPolledRefresh_Dec().pyclass

SubscriptionPolledRefreshSoapOut = ns3.SubscriptionPolledRefreshResponse_Dec().pyclass

SubscriptionCancelSoapIn = ns3.SubscriptionCancel_Dec().pyclass

SubscriptionCancelSoapOut = ns3.SubscriptionCancelResponse_Dec().pyclass

GetStatusSoapIn = ns3.GetStatus_Dec().pyclass

GetStatusSoapOut = ns3.GetStatusResponse_Dec().pyclass

BrowseSoapIn = ns3.Browse_Dec().pyclass

BrowseSoapOut = ns3.BrowseResponse_Dec().pyclass

ReadSoapIn = ns3.Read_Dec().pyclass

ReadSoapOut = ns3.ReadResponse_Dec().pyclass

WriteSoapIn = ns3.Write_Dec().pyclass

WriteSoapOut = ns3.WriteResponse_Dec().pyclass



################################################## 
# EchoServer_services.py 
# generated by ZSI.generate.wsdl2python
##################################################


from EchoServer_services_types import *
import urlparse, types
from ZSI.TCcompound import ComplexType, Struct
from ZSI import client
import ZSI

# Locator
class EchoServerLocator:
    EchoServer_address = "http://localhost:7000"
    def getEchoServerAddress(self):
        return EchoServerLocator.EchoServer_address
    def getEchoServer(self, url=None, **kw):
        return EchoServerSOAP(url or EchoServerLocator.EchoServer_address, **kw)

# Methods
class EchoServerSOAP:
    def __init__(self, url, **kw):
        kw.setdefault("readerclass", None)
        kw.setdefault("writerclass", None)
        # no resource properties
        self.binding = client.Binding(url=url, **kw)
        # no ws-addressing

    # op: Echo
    def Echo(self, request):
        if isinstance(request, EchoRequest) is False:
            raise TypeError, "%s incorrect request type" % (request.__class__)
        kw = {}
        # no input wsaction
        self.binding.Send(None, None, request, soapaction="Echo", **kw)
        # no output wsaction
        response = self.binding.Receive(EchoResponse.typecode)
        if isinstance(response, EchoResponse.typecode.pyclass) is False:
            raise TypeError, "%s incorrect response type" % (response.__class__)
        return response

EchoRequest = ns0.Echo_Dec().pyclass

EchoResponse = ns0.EchoResponse_Dec().pyclass



#!/usr/bin/env python

############################################################################
# David W. Robertson, LBNL
# See LBNLCopyright for copyright notice!
###########################################################################
import sys, unittest
from ServiceTest import ServiceTestCase, ServiceTestSuite
"""
Unittest for contacting the FreeDB Web service.

WSDL:  http://soap.systinet.net:6080/FreeDB/
"""

CONFIG_FILE = 'config.txt'
CONFIG_SECTION = 'complex_types'
SERVICE_NAME = 'com_systinet_demo_freedb_FreeDBService'
PORT_NAME = 'FreeDBService'


class FreeDBServiceTest(ServiceTestCase):
    """Test case for FreeDBService Web service
    """
    name = "test_FreeDBService"
    def setUp(self):
        ServiceTestCase.setSection(self,self.name)
        ServiceTestCase.setUp(self)
        
    def test_getDetails(self):
        """
        Request is a CDInfo
        """
        operationName = 'getDetails'
        request = self.getInputMessageInstance(operationName)
        request._title = 'Hollywood Town Hall'
        request._discId = '8509ff0a'
        request._artist = 'Jayhawks'
        request._category = 'rock'
        response = self.RPC(operationName, request)    

    def test_search(self):
        """
        Request is a string for this operation
        """
        operationName = "search"
        searchString = "Ted Nugent and the Amboy Dukes"
        response = self.RPC(operationName, searchString)

    def test_searchByTitle(self):
        """
        Request is a string for this operation
        """
        operationName = "searchByTitle"
        searchString = 'Ummagumma'
        response = self.RPC(operationName, searchString)

    def test_searchByTrack(self):
        """
        Request is a string for this operation
        """
        operationName = "searchByTrack"
        searchString = "Species of Animals"
        response = self.RPC(operationName, searchString)

    def test_searchByArtist(self):
        """
        Request is a string for this operation
        """
        operationName = "searchByArtist"
        searchString = "SteppenWolf"
        response = self.RPC(operationName, searchString)
    

def makeTestSuite():
    suite = ServiceTestSuite()
    suite.addTest(unittest.makeSuite(FreeDBServiceTest, "test_", suiteClass=ServiceTestSuite))
    return suite


if __name__ == "__main__" :
    unittest.TestProgram(defaultTest="makeTestSuite")




##################################################
# SessionCreateRQService_services_server.py
#      Generated by ZSI.generate.wsdl2dispatch.ServiceModuleWriter
#
##################################################

from SessionCreateRQService_services import *
from ZSI.ServiceContainer import ServiceSOAPBinding

class SessionCreateRQService(ServiceSOAPBinding):
    soapAction = {}
    root = {}
    _wsdl = """<?xml version=\"1.0\" ?>
<definitions targetNamespace=\"https://webservices.sabre.com/websvc\" xmlns=\"http://schemas.xmlsoap.org/wsdl/\" xmlns:eb=\"http://www.ebxml.org/namespaces/messageHeader\" xmlns:soap=\"http://schemas.xmlsoap.org/wsdl/soap/\" xmlns:tns=\"https://webservices.sabre.com/websvc\" xmlns:wsse=\"http://schemas.xmlsoap.org/ws/2002/12/secext\" xmlns:xs=\"http://www.w3.org/2001/XMLSchema\" xmlns:xsd1=\"http://www.opentravel.org/OTA/2002/11\" xmlns:xsd2=\"http://www.opentravel.org/OTA/2002/11\" xmlns:xsd3=\"http://www.opentravel.org/OTA/2002/08\">
	
	
	
	
	
	
	
	<message name=\"GetSessionCreateInput\">
		<part element=\"eb:MessageHeader\" name=\"header\"/>
		<part element=\"wsse:Security\" name=\"header2\"/>
		<part element=\"xsd1:SessionCreateRQ\" name=\"body\"/>
	</message>
	<message name=\"GetSessionCreateOutput\">
		<part element=\"eb:MessageHeader\" name=\"header\"/>
		<part element=\"wsse:Security\" name=\"header2\"/>
		<part element=\"xsd2:SessionCreateRS\" name=\"body\"/>
	</message>
	<portType name=\"SessionCreatePortType\">
		<operation name=\"SessionCreateRQ\">
			<input message=\"tns:GetSessionCreateInput\"/>
			<output message=\"tns:GetSessionCreateOutput\"/>
		</operation>
	</portType>
	<binding name=\"SessionCreateSoapBinding\" type=\"tns:SessionCreatePortType\">
		<soap:binding style=\"document\" transport=\"http://schemas.xmlsoap.org/soap/http\"/>
		<operation name=\"SessionCreateRQ\">
			<soap:operation soapAction=\"OTA\"/>
			<input>
				<soap:header message=\"tns:GetSessionCreateInput\" part=\"header\" use=\"literal\"/>
				<soap:header message=\"tns:GetSessionCreateInput\" part=\"header2\" use=\"literal\"/>
				<soap:body parts=\"body\" use=\"literal\"/>
			</input>
			<output>
				<soap:header message=\"tns:GetSessionCreateOutput\" part=\"header\" use=\"literal\"/>
				<soap:header message=\"tns:GetSessionCreateOutput\" part=\"header2\" use=\"literal\"/>
				<soap:body parts=\"body\" use=\"literal\"/>
			</output>
		</operation>
	</binding>
	<service name=\"SessionCreateRQService\">
		<port binding=\"tns:SessionCreateSoapBinding\" name=\"SessionCreatePortType\">
			<soap:address location=\"https://webservices.sabre.com/websvc\"/>
		</port>
	</service>
<schema attributeFormDefault=\"unqualified\" elementFormDefault=\"qualified\" targetNamespace=\"http://www.opentravel.org/OTA/2002/11\" xmlns=\"http://www.w3.org/2001/XMLSchema\" xmlns:tns=\"http://www.opentravel.org/OTA/2002/11\">
	
	

	<xs:element name=\"SessionCreateRQ\">
		<xs:complexType>
			<xs:sequence>
				<xs:element name=\"POS\">
					<xs:complexType>
						<xs:sequence>
							<xs:element name=\"Source\">
								<xs:complexType>
									<xs:attribute name=\"PseudoCityCode\" type=\"xs:string\" use=\"required\"/>
								</xs:complexType>
							</xs:element>
						</xs:sequence>
					</xs:complexType>
				</xs:element>
			</xs:sequence>
		</xs:complexType>
	</xs:element>
	<xs:element name=\"SessionCreateRS\">		<xs:complexType>			<xs:sequence>				<xs:element minOccurs=\"0\" name=\"Success\">					<xs:complexType/>				</xs:element>				<xs:element minOccurs=\"0\" name=\"Warnings\">					<xs:complexType>						<xs:sequence>							<xs:element name=\"Warning\">								<xs:complexType>									<xs:attribute name=\"Language\" type=\"xs:string\" use=\"optional\"/>									<xs:attribute name=\"ShortText\" type=\"xs:string\" use=\"optional\"/>									<xs:attribute name=\"Type\" type=\"xs:string\" use=\"optional\"/>									<xs:attribute name=\"Code\" use=\"optional\">										<xs:annotation>											<xs:documentation xml:lang=\"en\">If present, this refers to a table of coded values exchanged between applications to identify errors or warnings.</xs:documentation>										</xs:annotation>										<xs:simpleType>											<xs:annotation>												<xs:documentation xml:lang=\"en\">Used for codes in the OTA code tables.</xs:documentation>											</xs:annotation>											<xs:restriction base=\"xs:string\">												<xs:pattern value=\"[0-9A-Z]{1,3}\"/>											</xs:restriction>										</xs:simpleType>									</xs:attribute>									<xs:attribute name=\"DocURL\" type=\"xs:anyURI\" use=\"optional\">										<xs:annotation>											<xs:documentation xml:lang=\"en\">If present, this URL refers to an online description of the error that occurred.</xs:documentation>										</xs:annotation>									</xs:attribute>									<xs:attribute name=\"Status\" type=\"xs:string\" use=\"optional\">										<xs:annotation>											<xs:documentation xml:lang=\"en\">If present, recommended values are those enumerated in the OTA_ErrorRS, (NotProcessed | Incomplete | Complete | Unknown) however, the data type is designated as string data, recognizing that trading partners may identify additional status conditions not included in the enumeration.</xs:documentation>										</xs:annotation>									</xs:attribute>									<xs:attribute name=\"Tag\" type=\"xs:string\" use=\"optional\">										<xs:annotation>											<xs:documentation xml:lang=\"en\">If present, this attribute may identify an unknown or misspelled tag that caused an error in processing. It is recommended that the Tag attribute use XPath notation to identify the location of a tag in the event that more than one tag of the same name is present in the document. Alternatively, the tag name alone can be used to identify missing data [Type=ReqFieldMissing].</xs:documentation>										</xs:annotation>									</xs:attribute>									<xs:attribute name=\"RecordId\" type=\"xs:string\" use=\"optional\">										<xs:annotation>											<xs:documentation xml:lang=\"en\">If present, this attribute allows for batch processing and the identification of the record that failed amongst a group of records.</xs:documentation>										</xs:annotation>									</xs:attribute>								</xs:complexType>							</xs:element>						</xs:sequence>					</xs:complexType>				</xs:element>				<xs:element minOccurs=\"0\" name=\"ConversationId\" type=\"xs:string\"/>				<xs:element minOccurs=\"0\" name=\"Errors\">					<xs:complexType>						<xs:sequence>							<xs:element name=\"Error\">								<xs:complexType>									<xs:sequence>										<xs:element name=\"ErrorInfo\">											<xs:complexType>												<xs:sequence>													<xs:element name=\"Message\" type=\"xs:string\"/>												</xs:sequence>											</xs:complexType>										</xs:element>									</xs:sequence>									<xs:attribute name=\"ErrorCode\" type=\"xs:string\" use=\"required\"/>									<xs:attribute name=\"Severity\" type=\"xs:string\" use=\"required\"/>									<xs:attribute name=\"ErrorMessage\" type=\"xs:string\" use=\"required\"/>								</xs:complexType>							</xs:element>						</xs:sequence>					</xs:complexType>				</xs:element>			</xs:sequence>			<xs:attribute name=\"EchoToken\" use=\"optional\">				<xs:annotation>					<xs:documentation>A sequence number for additional message identification, assigned by the requesting host system. When a request 										message includes an echo token the corresponding response message MUST include an echo token with an identical value.											</xs:documentation>				</xs:annotation>				<xs:simpleType>					<xs:annotation>						<xs:documentation xml:lang=\"en\">Used for Character Strings, length 1 to 64</xs:documentation>					</xs:annotation>					<xs:restriction base=\"xs:string\">						<xs:minLength value=\"1\"/>						<xs:maxLength value=\"64\"/>					</xs:restriction>				</xs:simpleType>			</xs:attribute>			<xs:attribute name=\"TimeStamp\" type=\"xs:string\" use=\"optional\">				<xs:annotation>					<xs:documentation>Indicates the creation date and time of the message in UTC using the following format specified by ISO 8601; YYYY-	MM-					DDThh:mm:ssZ with time values using the 24 hour clock (e.g. 20 November 2003, 1:59:38 pm UTC becomes 2003-11-	20T13:59:38Z).						</xs:documentation>				</xs:annotation>			</xs:attribute>			<xs:attribute default=\"Production\" name=\"Target\" use=\"optional\">				<xs:annotation>					<xs:documentation>Used to indicate whether the request is for the Test or Production system.</xs:documentation>				</xs:annotation>				<xs:simpleType>					<xs:restriction base=\"xs:NMTOKEN\">						<xs:enumeration value=\"Test\"/>						<xs:enumeration value=\"Production\"/>					</xs:restriction>				</xs:simpleType>			</xs:attribute>			<xs:attribute name=\"version\" type=\"xs:string\" use=\"optional\">				<xs:annotation>					<xs:documentation>For all OTA versioned messages, the version of the message is indicated by a decimal value.</xs:documentation>				</xs:annotation>			</xs:attribute>			<xs:attribute name=\"SequenceNmbr\" type=\"xs:nonNegativeInteger\" use=\"optional\">				<xs:annotation>					<xs:documentation>Used to identify the sequence number of the transaction as assigned by the sending system; allows for an application 	to 					process messages in a certain order or to request a resynchronization of messages in the event that a system has been off-line and 	needs to 				retrieve messages that were missed. </xs:documentation>				</xs:annotation>			</xs:attribute>			<xs:attribute name=\"PrimaryLangID\" type=\"xs:language\" use=\"optional\">				<xs:annotation>					<xs:documentation>Identifes the primary language preference for the form of travel represented in a collection.
					 The human language is identified by ISO 639 codes.</xs:documentation>				</xs:annotation>			</xs:attribute>			<xs:attribute name=\"AltLangID\" type=\"xs:language\" use=\"optional\">				<xs:annotation>					<xs:documentation>Identifes the primary language preference for the form of travel represented in a collection.
					 The human language is identified by ISO 639 codes.</xs:documentation>				</xs:annotation>			</xs:attribute>			<xs:attribute name=\"status\" type=\"xs:string\" use=\"optional\"/>		</xs:complexType>	</xs:element></schema><schema attributeFormDefault=\"qualified\" elementFormDefault=\"qualified\" targetNamespace=\"http://www.ebxml.org/namespaces/messageHeader\" version=\"2.0c\" xmlns=\"http://www.w3.org/2001/XMLSchema\" xmlns:ds=\"http://www.w3.org/2000/09/xmldsig#\" xmlns:soap=\"http://schemas.xmlsoap.org/soap/envelope/\" xmlns:tns=\"http://www.ebxml.org/namespaces/messageHeader\" xmlns:xlink=\"http://www.w3.org/1999/xlink\">
	<import namespace=\"http://www.w3.org/2000/09/xmldsig#\" schemaLocation=\"xmldsig-core-schema.xsd\"/>
	<import namespace=\"http://www.w3.org/1999/xlink\" schemaLocation=\"xlink.xsd\"/>
	<import namespace=\"http://schemas.xmlsoap.org/soap/envelope/\" schemaLocation=\"envelope.xsd\"/>
	<import namespace=\"http://www.w3.org/XML/1998/namespace\" schemaLocation=\"xml.xsd\"/>
	<!-- MANIFEST, for use in soap:Body element -->
	<element name=\"Manifest\">
		<complexType>
			<sequence>
				<element maxOccurs=\"unbounded\" ref=\"tns:Reference\"/>
				<any maxOccurs=\"unbounded\" minOccurs=\"0\" namespace=\"##other\" processContents=\"lax\"/>
			</sequence>
			<attributeGroup ref=\"tns:bodyExtension.grp\"/>
		</complexType>
	</element>
	<element name=\"Reference\">
		<complexType>
			<sequence>
				<element maxOccurs=\"unbounded\" minOccurs=\"0\" ref=\"tns:Schema\"/>
				<element maxOccurs=\"unbounded\" minOccurs=\"0\" ref=\"tns:Description\"/>
				<any maxOccurs=\"unbounded\" minOccurs=\"0\" namespace=\"##other\" processContents=\"lax\"/>
			</sequence>
			<attribute ref=\"tns:id\"/>
			<attribute fixed=\"simple\" ref=\"xlink:type\"/>
			<attribute ref=\"xlink:href\" use=\"required\"/>
			<attribute ref=\"xlink:role\"/>
			<anyAttribute namespace=\"##other\" processContents=\"lax\"/>
		</complexType>
	</element>
	<element name=\"Schema\">
		<complexType>
			<attribute name=\"location\" type=\"anyURI\" use=\"required\"/>
			<attribute name=\"version\" type=\"tns:non-empty-string\"/>
		</complexType>
	</element>
	<!-- MESSAGEHEADER, for use in soap:Header element -->
	<element name=\"MessageHeader\">
		<complexType>
			<sequence>
				<element ref=\"tns:From\"/>
				<element ref=\"tns:To\"/>
				<element ref=\"tns:CPAId\"/>
				<element ref=\"tns:ConversationId\"/>
				<element ref=\"tns:Service\"/>
				<element ref=\"tns:Action\"/>
				<element ref=\"tns:MessageData\"/>
				<element minOccurs=\"0\" ref=\"tns:DuplicateElimination\"/>
				<element maxOccurs=\"unbounded\" minOccurs=\"0\" ref=\"tns:Description\"/>
				<any maxOccurs=\"unbounded\" minOccurs=\"0\" namespace=\"##other\" processContents=\"lax\"/>
			</sequence>
			<attributeGroup ref=\"tns:headerExtension.grp\"/>
		</complexType>
	</element>
	<element name=\"CPAId\" type=\"tns:non-empty-string\"/>
	<element name=\"ConversationId\" type=\"tns:non-empty-string\"/>
	<element name=\"Service\">
		<complexType>
			<simpleContent>
				<extension base=\"tns:non-empty-string\">
					<attribute name=\"type\" type=\"tns:non-empty-string\"/>
				</extension>
			</simpleContent>
		</complexType>
	</element>
	<element name=\"Action\" type=\"tns:non-empty-string\"/>
	<element name=\"MessageData\">
		<complexType>
			<sequence>
				<element ref=\"tns:MessageId\"/>
				<element ref=\"tns:Timestamp\"/>
				<element minOccurs=\"0\" ref=\"tns:RefToMessageId\"/>
				<element minOccurs=\"0\" ref=\"tns:TimeToLive\"/>
			</sequence>
		</complexType>
	</element>
	<element name=\"MessageId\" type=\"tns:non-empty-string\"/>
	<element name=\"TimeToLive\" type=\"dateTime\"/>
	<element name=\"DuplicateElimination\"/>
	<!-- SYNC REPLY, for use in soap:Header element -->
	<element name=\"SyncReply\">
		<complexType>
			<sequence>
				<any maxOccurs=\"unbounded\" minOccurs=\"0\" namespace=\"##other\" processContents=\"lax\"/>
			</sequence>
			<attributeGroup ref=\"tns:headerExtension.grp\"/>
			<attribute ref=\"soap:actor\" use=\"required\"/>
		</complexType>
	</element>
	<!-- MESSAGE ORDER, for use in soap:Header element -->
	<element name=\"MessageOrder\">
		<complexType>
			<sequence>
				<element ref=\"tns:SequenceNumber\"/>
				<any maxOccurs=\"unbounded\" minOccurs=\"0\" namespace=\"##other\" processContents=\"lax\"/>
			</sequence>
			<attributeGroup ref=\"tns:headerExtension.grp\"/>
		</complexType>
	</element>
	<element name=\"SequenceNumber\" type=\"tns:sequenceNumber.type\"/>
	<!-- ACK REQUESTED, for use in soap:Header element -->
	<element name=\"AckRequested\">
		<complexType>
			<sequence>
				<any maxOccurs=\"unbounded\" minOccurs=\"0\" namespace=\"##other\" processContents=\"lax\"/>
			</sequence>
			<attributeGroup ref=\"tns:headerExtension.grp\"/>
			<attribute ref=\"soap:actor\"/>
			<attribute name=\"signed\" type=\"boolean\" use=\"required\"/>
		</complexType>
	</element>
	<!-- ACKNOWLEDGMENT, for use in soap:Header element -->
	<element name=\"Acknowledgment\">
		<complexType>
			<sequence>
				<element ref=\"tns:Timestamp\"/>
				<element ref=\"tns:RefToMessageId\"/>
				<element minOccurs=\"0\" ref=\"tns:From\"/>
				<element maxOccurs=\"unbounded\" minOccurs=\"0\" ref=\"tns:Reference\"/>
				<any maxOccurs=\"unbounded\" minOccurs=\"0\" namespace=\"##other\" processContents=\"lax\"/>
			</sequence>
			<attributeGroup ref=\"tns:headerExtension.grp\"/>
			<attribute ref=\"soap:actor\"/>
		</complexType>
	</element>
	<!-- ERROR LIST, for use in soap:Header element -->
	<element name=\"ErrorList\">
		<complexType>
			<sequence>
				<element maxOccurs=\"unbounded\" ref=\"tns:Error\"/>
				<any maxOccurs=\"unbounded\" minOccurs=\"0\" namespace=\"##other\" processContents=\"lax\"/>
			</sequence>
			<attributeGroup ref=\"tns:headerExtension.grp\"/>
			<attribute name=\"highestSeverity\" type=\"tns:severity.type\" use=\"required\"/>
		</complexType>
	</element>
	<element name=\"Error\">
		<complexType>
			<sequence>
				<element minOccurs=\"0\" ref=\"tns:Description\"/>
				<any maxOccurs=\"unbounded\" minOccurs=\"0\" namespace=\"##other\" processContents=\"lax\"/>
			</sequence>
			<attribute ref=\"tns:id\"/>
			<attribute default=\"urn:oasis:names:tc:ebxml-msg:service:errors\" name=\"codeContext\" type=\"anyURI\"/>
			<attribute name=\"errorCode\" type=\"tns:non-empty-string\" use=\"required\"/>
			<attribute name=\"severity\" type=\"tns:severity.type\" use=\"required\"/>
			<attribute name=\"location\" type=\"tns:non-empty-string\"/>
			<anyAttribute namespace=\"##other\" processContents=\"lax\"/>
		</complexType>
	</element>
	<!-- STATUS RESPONSE, for use in soap:Body element -->
	<element name=\"StatusResponse\">
		<complexType>
			<sequence>
				<element ref=\"tns:RefToMessageId\"/>
				<element minOccurs=\"0\" ref=\"tns:Timestamp\"/>
				<any maxOccurs=\"unbounded\" minOccurs=\"0\" namespace=\"##other\" processContents=\"lax\"/>
			</sequence>
			<attributeGroup ref=\"tns:bodyExtension.grp\"/>
			<attribute name=\"messageStatus\" type=\"tns:messageStatus.type\" use=\"required\"/>
		</complexType>
	</element>
	<!-- STATUS REQUEST, for use in soap:Body element -->
	<element name=\"StatusRequest\">
		<complexType>
			<sequence>
				<element ref=\"tns:RefToMessageId\"/>
				<any maxOccurs=\"unbounded\" minOccurs=\"0\" namespace=\"##other\" processContents=\"lax\"/>
			</sequence>
			<attributeGroup ref=\"tns:bodyExtension.grp\"/>
		</complexType>
	</element>
	<!-- COMMON TYPES -->
	<complexType name=\"sequenceNumber.type\">
		<simpleContent>
			<extension base=\"nonNegativeInteger\">
				<attribute default=\"Continue\" name=\"status\" type=\"tns:status.type\"/>
			</extension>
		</simpleContent>
	</complexType>
	<simpleType name=\"status.type\">
		<restriction base=\"NMTOKEN\">
			<enumeration value=\"Reset\"/>
			<enumeration value=\"Continue\"/>
		</restriction>
	</simpleType>
	<simpleType name=\"messageStatus.type\">
		<restriction base=\"NMTOKEN\">
			<enumeration value=\"UnAuthorized\"/>
			<enumeration value=\"NotRecognized\"/>
			<enumeration value=\"Received\"/>
			<enumeration value=\"Processed\"/>
			<enumeration value=\"Forwarded\"/>
		</restriction>
	</simpleType>
	<simpleType name=\"non-empty-string\">
		<restriction base=\"string\">
			<minLength value=\"1\"/>
		</restriction>
	</simpleType>
	<simpleType name=\"severity.type\">
		<restriction base=\"NMTOKEN\">
			<enumeration value=\"Warning\"/>
			<enumeration value=\"Error\"/>
		</restriction>
	</simpleType>
	<!-- COMMON ATTRIBUTES and ATTRIBUTE GROUPS -->
	<attribute name=\"id\" type=\"ID\"/>
	<attribute name=\"version\" type=\"tns:non-empty-string\"/>
	<attributeGroup name=\"headerExtension.grp\">
		<attribute ref=\"tns:id\"/>
		<attribute ref=\"tns:version\" use=\"required\"/>
		<anyAttribute namespace=\"##other\" processContents=\"lax\"/>
		<!--attribute ref=\"soap:mustUnderstand\" use=\"optional\"/-->
	</attributeGroup>
	<attributeGroup name=\"bodyExtension.grp\">
		<attribute ref=\"tns:id\"/>
		<attribute ref=\"tns:version\" use=\"required\"/>
		<anyAttribute namespace=\"##other\" processContents=\"lax\"/>
	</attributeGroup>
	<!-- COMMON ELEMENTS -->
	<element name=\"PartyId\">
		<complexType>
			<simpleContent>
				<extension base=\"tns:non-empty-string\">
					<attribute name=\"type\" type=\"tns:non-empty-string\"/>
				</extension>
			</simpleContent>
		</complexType>
	</element>
	<element name=\"To\">
		<complexType>
			<sequence>
				<element maxOccurs=\"unbounded\" ref=\"tns:PartyId\"/>
				<element minOccurs=\"0\" name=\"Role\" type=\"tns:non-empty-string\"/>
			</sequence>
		</complexType>
	</element>
	<element name=\"From\">
		<complexType>
			<sequence>
				<element maxOccurs=\"unbounded\" ref=\"tns:PartyId\"/>
				<element minOccurs=\"0\" name=\"Role\" type=\"tns:non-empty-string\"/>
			</sequence>
		</complexType>
	</element>
	<element name=\"Description\">
		<complexType>
			<simpleContent>
				<extension base=\"tns:non-empty-string\">
					<attribute ref=\"xml:lang\" use=\"required\"/>
				</extension>
			</simpleContent>
		</complexType>
	</element>
	<element name=\"RefToMessageId\" type=\"tns:non-empty-string\"/>
	<element name=\"Timestamp\" type=\"string\"/>
</schema><schema elementFormDefault=\"qualified\" targetNamespace=\"http://www.w3.org/2000/09/xmldsig#\" version=\"0.1\" xmlns=\"http://www.w3.org/2001/XMLSchema\" xmlns:ds=\"http://www.w3.org/2000/09/xmldsig#\">
	<!-- Basic Types Defined for Signatures -->
	<simpleType name=\"CryptoBinary\">
		<restriction base=\"base64Binary\"/>
	</simpleType>
	<!-- Start Signature -->
	<element name=\"Signature\" type=\"ds:SignatureType\"/>
	<complexType name=\"SignatureType\">
		<sequence>
			<element ref=\"ds:SignedInfo\"/>
			<element ref=\"ds:SignatureValue\"/>
			<element minOccurs=\"0\" ref=\"ds:KeyInfo\"/>
			<element maxOccurs=\"unbounded\" minOccurs=\"0\" ref=\"ds:Object\"/>
		</sequence>
		<attribute name=\"Id\" type=\"ID\" use=\"optional\"/>
	</complexType>
	<element name=\"SignatureValue\" type=\"ds:SignatureValueType\"/>
	<complexType name=\"SignatureValueType\">
		<simpleContent>
			<extension base=\"base64Binary\">
				<attribute name=\"Id\" type=\"ID\" use=\"optional\"/>
			</extension>
		</simpleContent>
	</complexType>
	<!-- Start SignedInfo -->
	<element name=\"SignedInfo\" type=\"ds:SignedInfoType\"/>
	<complexType name=\"SignedInfoType\">
		<sequence>
			<element ref=\"ds:CanonicalizationMethod\"/>
			<element ref=\"ds:SignatureMethod\"/>
			<element maxOccurs=\"unbounded\" ref=\"ds:Reference\"/>
		</sequence>
		<attribute name=\"Id\" type=\"ID\" use=\"optional\"/>
	</complexType>
	<element name=\"CanonicalizationMethod\" type=\"ds:CanonicalizationMethodType\"/>
	<complexType mixed=\"true\" name=\"CanonicalizationMethodType\">
		<sequence>
			<any maxOccurs=\"unbounded\" minOccurs=\"0\" namespace=\"##any\"/>
			<!-- (0,unbounded) elements from (1,1) namespace -->
		</sequence>
		<attribute name=\"Algorithm\" type=\"anyURI\" use=\"required\"/>
	</complexType>
	<element name=\"SignatureMethod\" type=\"ds:SignatureMethodType\"/>
	<complexType mixed=\"true\" name=\"SignatureMethodType\">
		<sequence>
			<element minOccurs=\"0\" name=\"HMACOutputLength\" type=\"ds:HMACOutputLengthType\"/>
			<any maxOccurs=\"unbounded\" minOccurs=\"0\" namespace=\"##other\"/>
			<!-- (0,unbounded) elements from (1,1) external namespace -->
		</sequence>
		<attribute name=\"Algorithm\" type=\"anyURI\" use=\"required\"/>
	</complexType>
	<!-- Start Reference -->
	<element name=\"Reference\" type=\"ds:ReferenceType\"/>
	<complexType name=\"ReferenceType\">
		<sequence>
			<element minOccurs=\"0\" ref=\"ds:Transforms\"/>
			<element ref=\"ds:DigestMethod\"/>
			<element ref=\"ds:DigestValue\"/>
		</sequence>
		<attribute name=\"Id\" type=\"ID\" use=\"optional\"/>
		<attribute name=\"URI\" type=\"anyURI\" use=\"optional\"/>
		<attribute name=\"Type\" type=\"anyURI\" use=\"optional\"/>
	</complexType>
	<element name=\"Transforms\" type=\"ds:TransformsType\"/>
	<complexType name=\"TransformsType\">
		<sequence>
			<element maxOccurs=\"unbounded\" ref=\"ds:Transform\"/>
		</sequence>
	</complexType>
	<element name=\"Transform\" type=\"ds:TransformType\"/>
	<complexType mixed=\"true\" name=\"TransformType\">
		<choice maxOccurs=\"unbounded\" minOccurs=\"0\">
			<any namespace=\"##other\" processContents=\"lax\"/>
			<element name=\"XPath\" type=\"string\"/>
			<!-- (1,1) elements from (0,unbounded) namespaces -->
		</choice>
		<attribute name=\"Algorithm\" type=\"anyURI\" use=\"required\"/>
	</complexType>
	<!-- End Reference -->
	<element name=\"DigestMethod\" type=\"ds:DigestMethodType\"/>
	<complexType mixed=\"true\" name=\"DigestMethodType\">
		<sequence>
			<any maxOccurs=\"unbounded\" minOccurs=\"0\" namespace=\"##other\" processContents=\"lax\"/>
		</sequence>
		<attribute name=\"Algorithm\" type=\"anyURI\" use=\"required\"/>
	</complexType>
	<element name=\"DigestValue\" type=\"ds:DigestValueType\"/>
	<simpleType name=\"DigestValueType\">
		<restriction base=\"base64Binary\"/>
	</simpleType>
	<!-- End SignedInfo -->
	<!-- Start KeyInfo -->
	<element name=\"KeyInfo\" type=\"ds:KeyInfoType\"/>
	<complexType mixed=\"true\" name=\"KeyInfoType\">
		<choice maxOccurs=\"unbounded\">
			<element ref=\"ds:KeyName\"/>
			<element ref=\"ds:KeyValue\"/>
			<element ref=\"ds:RetrievalMethod\"/>
			<element ref=\"ds:X509Data\"/>
			<element ref=\"ds:PGPData\"/>
			<element ref=\"ds:SPKIData\"/>
			<element ref=\"ds:MgmtData\"/>
			<any namespace=\"##other\" processContents=\"lax\"/>
			<!-- (1,1) elements from (0,unbounded) namespaces -->
		</choice>
		<attribute name=\"Id\" type=\"ID\" use=\"optional\"/>
	</complexType>
	<element name=\"KeyName\" type=\"string\"/>
	<element name=\"MgmtData\" type=\"string\"/>
	<element name=\"KeyValue\" type=\"ds:KeyValueType\"/>
	<complexType mixed=\"true\" name=\"KeyValueType\">
		<choice>
			<element ref=\"ds:DSAKeyValue\"/>
			<element ref=\"ds:RSAKeyValue\"/>
			<any namespace=\"##other\" processContents=\"lax\"/>
		</choice>
	</complexType>
	<element name=\"RetrievalMethod\" type=\"ds:RetrievalMethodType\"/>
	<complexType name=\"RetrievalMethodType\">
		<sequence>
			<element minOccurs=\"0\" ref=\"ds:Transforms\"/>
		</sequence>
		<attribute name=\"URI\" type=\"anyURI\"/>
		<attribute name=\"Type\" type=\"anyURI\" use=\"optional\"/>
	</complexType>
	<!-- Start X509Data -->
	<element name=\"X509Data\" type=\"ds:X509DataType\"/>
	<complexType name=\"X509DataType\">
		<sequence maxOccurs=\"unbounded\">
			<choice>
				<element name=\"X509IssuerSerial\" type=\"ds:X509IssuerSerialType\"/>
				<element name=\"X509SKI\" type=\"base64Binary\"/>
				<element name=\"X509SubjectName\" type=\"string\"/>
				<element name=\"X509Certificate\" type=\"base64Binary\"/>
				<element name=\"X509CRL\" type=\"base64Binary\"/>
				<any namespace=\"##other\" processContents=\"lax\"/>
			</choice>
		</sequence>
	</complexType>
	<complexType name=\"X509IssuerSerialType\">
		<sequence>
			<element name=\"X509IssuerName\" type=\"string\"/>
			<element name=\"X509SerialNumber\" type=\"integer\"/>
		</sequence>
	</complexType>
	<!-- End X509Data -->
	<!-- Begin PGPData -->
	<element name=\"PGPData\" type=\"ds:PGPDataType\"/>
	<complexType name=\"PGPDataType\">
		<sequence>
			<element name=\"PGPKeyID\" type=\"base64Binary\"/>
			<element minOccurs=\"0\" name=\"PGPKeyPacket\" type=\"base64Binary\"/>
			<any maxOccurs=\"unbounded\" minOccurs=\"0\" namespace=\"##other\" processContents=\"lax\"/>
		</sequence>
	</complexType>
	<!-- End PGPData -->
	<!-- Begin SPKIData -->
	<element name=\"SPKIData\" type=\"ds:SPKIDataType\"/>
	<complexType name=\"SPKIDataType\">
		<sequence maxOccurs=\"unbounded\">
			<element name=\"SPKISexp\" type=\"base64Binary\"/>
			<any minOccurs=\"0\" namespace=\"##other\" processContents=\"lax\"/>
		</sequence>
	</complexType>
	<!-- End SPKIData -->
	<!-- End KeyInfo -->
	<!-- Start Object (Manifest, SignatureProperty) -->
	<element name=\"Object\" type=\"ds:ObjectType\"/>
	<complexType mixed=\"true\" name=\"ObjectType\">
		<sequence maxOccurs=\"unbounded\" minOccurs=\"0\">
			<any namespace=\"##any\" processContents=\"lax\"/>
		</sequence>
		<attribute name=\"Id\" type=\"ID\" use=\"optional\"/>
		<attribute name=\"MimeType\" type=\"string\" use=\"optional\"/>
		<attribute name=\"Encoding\" type=\"anyURI\" use=\"optional\"/>
		<!-- add a grep facet -->
	</complexType>
	<element name=\"Manifest\" type=\"ds:ManifestType\"/>
	<complexType name=\"ManifestType\">
		<sequence>
			<element maxOccurs=\"unbounded\" ref=\"ds:Reference\"/>
		</sequence>
		<attribute name=\"Id\" type=\"ID\" use=\"optional\"/>
	</complexType>
	<element name=\"SignatureProperties\" type=\"ds:SignaturePropertiesType\"/>
	<complexType name=\"SignaturePropertiesType\">
		<sequence>
			<element maxOccurs=\"unbounded\" ref=\"ds:SignatureProperty\"/>
		</sequence>
		<attribute name=\"Id\" type=\"ID\" use=\"optional\"/>
	</complexType>
	<element name=\"SignatureProperty\" type=\"ds:SignaturePropertyType\"/>
	<complexType mixed=\"true\" name=\"SignaturePropertyType\">
		<choice maxOccurs=\"unbounded\">
			<any namespace=\"##other\" processContents=\"lax\"/>
			<!-- (1,1) elements from (1,unbounded) namespaces -->
		</choice>
		<attribute name=\"Target\" type=\"anyURI\" use=\"required\"/>
		<attribute name=\"Id\" type=\"ID\" use=\"optional\"/>
	</complexType>
	<!-- End Object (Manifest, SignatureProperty) -->
	<!-- Start Algorithm Parameters -->
	<simpleType name=\"HMACOutputLengthType\">
		<restriction base=\"integer\"/>
	</simpleType>
	<!-- Start KeyValue Element-types -->
	<element name=\"DSAKeyValue\" type=\"ds:DSAKeyValueType\"/>
	<complexType name=\"DSAKeyValueType\">
		<sequence>
			<sequence minOccurs=\"0\">
				<element name=\"P\" type=\"ds:CryptoBinary\"/>
				<element name=\"Q\" type=\"ds:CryptoBinary\"/>
			</sequence>
			<element minOccurs=\"0\" name=\"G\" type=\"ds:CryptoBinary\"/>
			<element name=\"Y\" type=\"ds:CryptoBinary\"/>
			<element minOccurs=\"0\" name=\"J\" type=\"ds:CryptoBinary\"/>
			<sequence minOccurs=\"0\">
				<element name=\"Seed\" type=\"ds:CryptoBinary\"/>
				<element name=\"PgenCounter\" type=\"ds:CryptoBinary\"/>
			</sequence>
		</sequence>
	</complexType>
	<element name=\"RSAKeyValue\" type=\"ds:RSAKeyValueType\"/>
	<complexType name=\"RSAKeyValueType\">
		<sequence>
			<element name=\"Modulus\" type=\"ds:CryptoBinary\"/>
			<element name=\"Exponent\" type=\"ds:CryptoBinary\"/>
		</sequence>
	</complexType>
	<!-- End KeyValue Element-types -->
	<!-- End Signature -->
</schema><xsd:schema attributeFormDefault=\"qualified\" elementFormDefault=\"qualified\" targetNamespace=\"http://www.w3.org/1999/xlink\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" xmlns:xsd=\"http://www.w3.org/2001/XMLSchema\">
	<xsd:element name=\"root\">
		<xsd:annotation>
			<xsd:documentation>Comment describing your root element</xsd:documentation>
		</xsd:annotation>
	</xsd:element>
	<xsd:attribute name=\"type\">
	<xsd:simpleType>
		<xsd:restriction base=\"xsd:NMTOKEN\">
			<xsd:enumeration value=\"simple\"/>
			<xsd:enumeration value=\"extended\"/>
			<xsd:enumeration value=\"locator\"/>
			<xsd:enumeration value=\"arc\"/>
			<xsd:enumeration value=\"resource\"/>
			<xsd:enumeration value=\"title\"/>
			<xsd:enumeration value=\"none\"/>
		</xsd:restriction>
	</xsd:simpleType>
	</xsd:attribute>
	<xsd:attribute name=\"href\" type=\"xsd:anyURI\">
	</xsd:attribute>
	<xsd:attribute name=\"role\" type=\"xsd:anyURI\">
	</xsd:attribute>
	<xsd:attribute name=\"arcrole\" type=\"xsd:anyURI\">
	</xsd:attribute>
	<xsd:attribute name=\"title\" type=\"xsd:string\">
	</xsd:attribute>
	<xsd:attribute name=\"label\" type=\"xsd:NMTOKEN\">
	</xsd:attribute>
	<xsd:attribute name=\"show\">
		<xsd:simpleType>
			<xsd:restriction base=\"xsd:NMTOKEN\">
				<xsd:enumeration value=\"new\"/>
				<xsd:enumeration value=\"replace\"/>
				<xsd:enumeration value=\"embed\"/>
				<xsd:enumeration value=\"other\"/>
				<xsd:enumeration value=\"none\"/>
			</xsd:restriction>
		</xsd:simpleType>
	</xsd:attribute>
</xsd:schema><schema targetNamespace=\"http://schemas.xmlsoap.org/soap/envelope/\" xmlns=\"http://www.w3.org/2001/XMLSchema\" xmlns:tns=\"http://schemas.xmlsoap.org/soap/envelope/\">
	

	<!-- Envelope, header and body -->
	<xs:element name=\"Envelope\" type=\"tns:Envelope\"/>
	<xs:complexType name=\"Envelope\">
		<xs:sequence>
			<xs:element maxOccurs=\"unbounded\" minOccurs=\"0\" ref=\"tns:Header\"/>
			<xs:element ref=\"tns:Body\"/>
			<xs:any maxOccurs=\"unbounded\" minOccurs=\"0\" namespace=\"##other\" processContents=\"lax\"/>
		</xs:sequence>
		<xs:anyAttribute namespace=\"##other\" processContents=\"lax\"/>
	</xs:complexType>
	<xs:element name=\"Header\" type=\"tns:Header\"/>
	<xs:complexType name=\"Header\">
		<xs:sequence>
			<xs:any maxOccurs=\"unbounded\" minOccurs=\"0\" namespace=\"##other\" processContents=\"lax\"/>
		</xs:sequence>
		<xs:anyAttribute namespace=\"##other\" processContents=\"lax\"/>
	</xs:complexType>
	<xs:element name=\"Body\" type=\"tns:Body\"/>
	<xs:complexType name=\"Body\">
		<xs:sequence>
			<xs:any maxOccurs=\"unbounded\" minOccurs=\"0\" namespace=\"##any\" processContents=\"lax\"/>
		</xs:sequence>
		<xs:anyAttribute namespace=\"##any\" processContents=\"lax\">
			<xs:annotation>
				<xs:documentation>
		  Prose in the spec does not specify that attributes are allowed on the Body element
		</xs:documentation>
			</xs:annotation>
		</xs:anyAttribute>
	</xs:complexType>
	<!-- Global Attributes.  The following attributes are intended to be usable via qualified attribute names on any complex type referencing them.  -->
	<xs:attribute name=\"mustUnderstand\">
		<xs:simpleType>
			<xs:restriction base=\"xs:boolean\">
				<xs:pattern value=\"0|1\"/>
			</xs:restriction>
		</xs:simpleType>
	</xs:attribute>
	<xs:attribute name=\"actor\" type=\"xs:anyURI\"/>
	<xs:simpleType name=\"encodingStyle\">
		<xs:annotation>
			<xs:documentation>
	    'encodingStyle' indicates any canonicalization conventions followed in the contents of the containing element.  For example, the value 'http://schemas.xmlsoap.org/soap/encoding/' indicates the pattern described in SOAP specification
	  </xs:documentation>
		</xs:annotation>
		<xs:list itemType=\"xs:anyURI\"/>
	</xs:simpleType>
	<xs:attribute name=\"encodingStyle\" type=\"tns:encodingStyle\"/>
	<xs:attributeGroup name=\"encodingStyle\">
		<xs:attribute ref=\"tns:encodingStyle\"/>
	</xs:attributeGroup>
	<xs:element name=\"Fault\" type=\"tns:Fault\"/>
	<xs:complexType final=\"extension\" name=\"Fault\">
		<xs:annotation>
			<xs:documentation>
	    Fault reporting structure
	  </xs:documentation>
		</xs:annotation>
		<xs:sequence>
			<xs:element name=\"faultcode\" type=\"xs:QName\"/>
			<xs:element name=\"faultstring\" type=\"xs:string\"/>
			<xs:element minOccurs=\"0\" name=\"faultactor\" type=\"xs:anyURI\"/>
			<xs:element minOccurs=\"0\" name=\"detail\" type=\"tns:detail\"/>
		</xs:sequence>
	</xs:complexType>
	<xs:complexType name=\"detail\">
		<xs:sequence>
			<xs:any maxOccurs=\"unbounded\" minOccurs=\"0\" namespace=\"##any\" processContents=\"lax\"/>
		</xs:sequence>
		<xs:anyAttribute namespace=\"##any\" processContents=\"lax\"/>
	</xs:complexType>
</schema><xs:schema targetNamespace=\"http://www.w3.org/XML/1998/namespace\" xml:lang=\"en\" xmlns:xs=\"http://www.w3.org/2001/XMLSchema\">
	<xs:annotation>
		<xs:documentation>
   See http://www.w3.org/XML/1998/namespace.html and
   http://www.w3.org/TR/REC-xml for information about this namespace.
  </xs:documentation>
	</xs:annotation>
	<xs:annotation>
		<xs:documentation>This schema defines attributes and an attribute group
        suitable for use by
        schemas wishing to allow xml:base, xml:lang or xml:space attributes
        on elements they define.

        To enable this, such a schema must import this schema
        for the XML namespace, e.g. as follows:
        &lt;schema . . .&gt;
         . . .
         &lt;import namespace=&quot;http://www.w3.org/XML/1998/namespace&quot;
                    schemaLocation=&quot;http://www.w3.org/2001/03/xml.xsd&quot;/&gt;

        Subsequently, qualified reference to any of the attributes
        or the group defined below will have the desired effect, e.g.

        &lt;type . . .&gt;
         . . .
         &lt;attributeGroup ref=&quot;xml:specialAttrs&quot;/&gt;
 
         will define a type which will schema-validate an instance
         element with any of those attributes</xs:documentation>
	</xs:annotation>
	<xs:annotation>
		<xs:documentation>In keeping with the XML Schema WG's standard versioning
   policy, this schema document will persist at
   http://www.w3.org/2001/03/xml.xsd.
   At the date of issue it can also be found at
   http://www.w3.org/2001/xml.xsd.
   The schema document at that URI may however change in the future,
   in order to remain compatible with the latest version of XML Schema
   itself.  In other words, if the XML Schema namespace changes, the version
   of this document at
   http://www.w3.org/2001/xml.xsd will change
   accordingly; the version at
   http://www.w3.org/2001/03/xml.xsd will not change.
  </xs:documentation>
	</xs:annotation>
	<xs:attribute name=\"lang\" type=\"xs:language\">
		<xs:annotation>
			<xs:documentation>In due course, we should install the relevant ISO 2- and 3-letter
         codes as the enumerated possible values . . .</xs:documentation>
		</xs:annotation>
	</xs:attribute>
	<xs:attribute default=\"preserve\" name=\"space\">
		<xs:simpleType>
			<xs:restriction base=\"xs:NCName\">
				<xs:enumeration value=\"default\"/>
				<xs:enumeration value=\"preserve\"/>
			</xs:restriction>
		</xs:simpleType>
	</xs:attribute>
	<xs:attribute name=\"base\" type=\"xs:anyURI\">
		<xs:annotation>
			<xs:documentation>See http://www.w3.org/TR/xmlbase/ for
                     information about this attribute.</xs:documentation>
		</xs:annotation>
	</xs:attribute>
	<xs:attributeGroup name=\"specialAttrs\">
		<xs:attribute ref=\"xml:base\"/>
		<xs:attribute ref=\"xml:lang\"/>
		<xs:attribute ref=\"xml:space\"/>
	</xs:attributeGroup>
</xs:schema><xs:schema attributeFormDefault=\"qualified\" elementFormDefault=\"qualified\" targetNamespace=\"http://schemas.xmlsoap.org/ws/2002/12/secext\" xmlns=\"http://www.w3.org/2001/XMLSchema\" xmlns:app2=\"http://schemas.xmlsoap.org/ws/2002/12/secext\" xmlns:msdata=\"urn:schemas-microsoft-com:xml-msdata\" xmlns:xs=\"http://www.w3.org/2001/XMLSchema\" xmlns:xsse=\"http://schemas.xmlsoap.org/ws/2002/12/secext\">
	<xs:element msdata:Prefix=\"wsse\" name=\"Security\">
		<xs:complexType>
			<xs:sequence>
				<xs:element minOccurs=\"0\" msdata:Prefix=\"wsse\" name=\"UsernameToken\">
					<xs:complexType>
						<xs:sequence>
							<xs:element minOccurs=\"0\" msdata:Prefix=\"wsse\" name=\"Username\" type=\"xs:string\"/>
							<xs:element minOccurs=\"0\" msdata:Prefix=\"wsse\" name=\"Password\" type=\"xs:string\"/>
							<xs:element form=\"unqualified\" minOccurs=\"0\" name=\"Organization\" type=\"xs:string\"/>
							<xs:element form=\"unqualified\" minOccurs=\"0\" name=\"Domain\" type=\"xs:string\"/>
						</xs:sequence>
					</xs:complexType>
				</xs:element>
				<xs:element minOccurs=\"0\" msdata:Prefix=\"wsse\" name=\"BinarySecurityToken\" type=\"xs:string\">
					<!--xs:complexType>
						<xs:attribute name=\"EncodingType\" type=\"xs:string\" use=\"optional\"/>
						<xs:attribute name=\"valueType\" type=\"xs:string\" use=\"optional\"/>						
					</xs:complexType-->
				</xs:element>
				<!-- Response Elements -->
			</xs:sequence>
		</xs:complexType>
	</xs:element>
</xs:schema></definitions>"""

    def __init__(self, post='/websvc', **kw):
        ServiceSOAPBinding.__init__(self, post)

    def soap_SessionCreateRQ(self, ps):
        self.request = ps.Parse(GetSessionCreateInput.typecode)
        return GetSessionCreateOutput()

    soapAction['OTA'] = 'soap_SessionCreateRQ'
    root[(GetSessionCreateInput.typecode.nspname,GetSessionCreateInput.typecode.pname)] = 'soap_SessionCreateRQ'




#!/usr/bin/env python

############################################################################
# David W. Robertson, LBNL
# See LBNLCopyright for copyright notice!
###########################################################################
import sys, unittest
from ServiceTest import ServiceTestCase, ServiceTestSuite


"""
Unittest for contacting the threatService Web service.

WSDL:  http://www.boyzoid.com/threat.cfc?wsdl
"""

CONFIG_FILE = 'config.txt'
CONFIG_SECTION = 'complex_types'
SERVICE_NAME = 'threatService'

PORT_NAME = 'threat'


class threatServiceTest(ServiceTestCase):
    """Test case for threatService Web service
    """
    name = "test_ThreatService"

    def setUp(self):
        ServiceTestCase.setSection(self,self.name)
        ServiceTestCase.setUp(self)
        
    def test_threatLevel(self):
        operationName = 'threatLevel'
        request = self.getInputMessageInstance(operationName)
        response = self.RPC(operationName, request)
        



def makeTestSuite():
    suite = ServiceTestSuite()
    suite.addTest(unittest.makeSuite(threatServiceTest, 'test_'))
    return suite


if __name__ == "__main__" :
    unittest.TestProgram(defaultTest="makeTestSuite")



#!/usr/bin/env python

############################################################################
# David W. Robertson, LBNL
# See LBNLCopyright for copyright notice!
###########################################################################
import unittest
from ServiceTest import ServiceTestCase, ServiceTestSuite
"""
Unittest for contacting the GlobalWeather portType for the
GlobalWeather Web service.

WSDL:  http://live.capescience.com/wsdl/GlobalWeather.wsdl
"""

CONFIG_FILE = 'config.txt'
CONFIG_SECTION = 'complex_types'
SERVICE_NAME = 'GlobalWeather'
PORT_NAME = 'GlobalWeather'


class GlobalWeatherTest(ServiceTestCase):
    """Test case for GlobalWeather Web service, port type GlobalWeather
    """

    name = "test_GlobalWeather_gw"
    
    def setUp(self):
        self._portName = "GlobalWeather"
        ServiceTestCase.setSection(self,self.name)
        ServiceTestCase.setUp(self)
        
        
    
           # requires a floating point ZSI typecode; in progress
    def test_getWeatherReport(self):
        """
        This test raises a ZSI.EvaluateException
        """
        operationName = "getWeatherReport"
        request = self.getInputMessageInstance(operationName)
        request._code = 'SFO'
        self.RPC(operationName, request)    
    


def makeTestSuite():
    suite = ServiceTestSuite()
    suite.addTest(unittest.makeSuite(GlobalWeatherTest, 'test_'))
    return suite


if __name__ == "__main__" :
    unittest.TestProgram(defaultTest="makeTestSuite")



#!/usr/bin/env python
############################################################################
# Joshua R. Boverhof, LBNL
# See LBNLCopyright for copyright notice!
###########################################################################
import os, sys, unittest
from ServiceTest import ServiceTestCase, ServiceTestSuite
from ZSI import FaultException
from ZSI.TC import _get_global_element_declaration as GED
from ZSI.writer import SoapWriter

"""
Unittest for Bug Report 
[ 1441574 ] ZSI assumes minOccurs(1) for all parts

WSDL:  
"""

CONFIG_FILE = 'config.txt'
sys.path.append('%s/%s' %(os.getcwd(), 'stubs'))

class ChoiceTest(unittest.TestCase):
    name = "test_Choice"
    done = False

    def setUp(self):
        if ChoiceTest.done: return
        ChoiceTest.done = True
        wsdl = os.path.abspath('test_Choice.xsd').strip()
        fin,fout = os.popen4('cd stubs; wsdl2py.py -x -b -f %s' %wsdl)
        # TODO: wait for wsdl2py.py to finish.
        for i in fout: print i
        import test_Choice_xsd_services_types
 
    def tearDown(self):
        pass

    def test_choice_default_facets_legal1(self):
        """<choice minOccurs=1 maxOccurs=1>
        """
        pyobj = GED("urn:example", "Easy").pyclass()
        pyobj.Rank = 1
        sw = SoapWriter()
        sw.serialize(pyobj)
        print str(sw)

    def test_choice_maxOccurs_unbounded(self):
        """<choice minOccurs=1 maxOccurs=unbounded>
        """
        pyobj = GED("urn:example", "Hard").pyclass()
        pyobj.Name = "steve"
        pyobj.Name.append("mark")
        pyobj.Any = "whatever"
        pyobj.Rank = 2
        pyobj.Rank.append(3)
        pyobj.Rank.append(4)
        sw = SoapWriter()
        sw.serialize(pyobj)
        print str(sw)



def makeTestSuite():
    suite = ServiceTestSuite()
    suite.addTest(unittest.makeSuite(ChoiceTest, "test_", suiteClass=ServiceTestSuite))
    return suite


if __name__ == "__main__" :
    unittest.TestProgram(defaultTest="makeTestSuite")




#! /usr/bin/env python

# This script does not use 2.x features so that you can build an RPM
# on a system that doesn't have 2.x installed (e.g., basic RedHat).

import ConfigParser
import os
import sys
import time

cf = ConfigParser.ConfigParser()
cf.read('setup.cfg')

major = cf.getint('version', 'major')
minor = cf.getint('version', 'minor')
patchlevel = cf.getint('version', 'patchlevel')

if '--incr' in sys.argv[1:]:
    patchlevel = patchlevel + 1
    cf.set('version', 'patchlevel', patchlevel)
    f = open('setup.cfg', 'w')
    cf.write(f)
    f.close()

def write_changes(filename, text):
    """Write text to the file only if the text changed."""
    oldtext = None
    if os.path.exists(filename):
        f = open(filename)
        oldtext = f.read()
        f.close()
    if oldtext != text:
        f = open(filename, 'w')
        f.write(text)
        f.close()

write_changes('ZSI/version.py',
              '# Auto-generated file; do not edit\n'
              'Version = (%d, %d, %d)\n' % (major, minor, patchlevel))

write_changes('doc/version.tex',
              '% Auto-generated file; do not edit\n'
              + time.strftime('\\date{%B %d, %Y}\n', time.localtime())
              + ('\\release{%d.%d.%d}\n' % (major, minor, patchlevel))
              + ('\\setshortversion{%d.%d}\n' % (major, minor)))



################################################## 
# test_Attributes_xsd_services_types.py 
# generated by ZSI.generate.wsdl2python
##################################################


import ZSI
import ZSI.TCcompound
from ZSI.TC import ElementDeclaration,TypeDefinition
from ZSI.generate.pyclass import pyclass_type

##############################
# targetNamespace
# urn:example
##############################

class ns0:
    targetNamespace = "urn:example"

    class Test1_Def(ZSI.TCcompound.ComplexType, TypeDefinition):
        schema = "urn:example"
        type = (schema, "Test1")
        def __init__(self, pname, ofwhat=(), attributes=None, extend=False, restrict=False, **kw):
            ns = ns0.Test1_Def.schema
            TClist = []
            self.attribute_typecode_dict = attributes or {}
            if extend: TClist += ofwhat
            if restrict: TClist = ofwhat
            else:
                # attribute handling code
                self.attribute_typecode_dict["myInt"] = ZSI.TCnumbers.Iint()
                self.attribute_typecode_dict[("urn:example","myDouble")] = ZSI.TCnumbers.FPdouble()
                self.attribute_typecode_dict[("urn:example","myString")] = ZSI.TC.String()
                self.attribute_typecode_dict["myFloat"] = ZSI.TCnumbers.FPfloat()
                self.attribute_typecode_dict["myDecimal"] = ZSI.TC.Decimal()
                self.attribute_typecode_dict["myDuration"] = ZSI.TCtimes.Duration()
                self.attribute_typecode_dict["myDateTime"] = ZSI.TCtimes.gDateTime()
                self.attribute_typecode_dict["myTime"] = ZSI.TCtimes.gTime()
                self.attribute_typecode_dict["myDate"] = ZSI.TCtimes.gDate()
                self.attribute_typecode_dict["myGYearMonth"] = ZSI.TCtimes.gYearMonth()
                self.attribute_typecode_dict["myGYear"] = ZSI.TCtimes.gYear()
                self.attribute_typecode_dict["myGMonthDay"] = ZSI.TCtimes.gMonthDay()
                self.attribute_typecode_dict["myGDay"] = ZSI.TCtimes.gDay()
                self.attribute_typecode_dict["myGMonth"] = ZSI.TCtimes.gMonth()
                self.attribute_typecode_dict["myHexBinary"] = ZSI.TC.HexBinaryString()
                self.attribute_typecode_dict["myBase64Binary"] = ZSI.TC.Base64String()
                self.attribute_typecode_dict["myAnyURI"] = ZSI.TC.URI()
                self.attribute_typecode_dict["myQName"] = ZSI.TC.QName()
                self.attribute_typecode_dict["myNOTATION"] = ZSI.TC.AnyType()
            ZSI.TCcompound.ComplexType.__init__(self, None, TClist, pname=pname, inorder=0, **kw)
            class Holder:
                __metaclass__ = pyclass_type
                typecode = self
                def __init__(self):
                    # pyclass
                    return
            Holder.__name__ = "Test1_Holder"
            self.pyclass = Holder

    class Test1_Dec(ElementDeclaration):
        literal = "Test1"
        schema = "urn:example"
        def __init__(self, **kw):
            kw["pname"] = ("urn:example","Test1")
            kw["aname"] = "_Test1"
            if ns0.Test1_Def not in ns0.Test1_Dec.__bases__:
                bases = list(ns0.Test1_Dec.__bases__)
                bases.insert(0, ns0.Test1_Def)
                ns0.Test1_Dec.__bases__ = tuple(bases)

            ns0.Test1_Def.__init__(self, **kw)
            if self.pyclass is not None: self.pyclass.__name__ = "Test1_Dec_Holder"

# end class ns0 (tns: urn:example)
